# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class SendNotification(BaseModel):
    send_notification: Optional["SendNotificationSendNotification"] = Field(
        alias="sendNotification"
    )


class SendNotificationSendNotification(BaseModel):
    result: Optional[bool]


SendNotification.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountEmotions(BaseModel):
    count_emotions: Optional["CountEmotionsCountEmotions"] = Field(
        alias="countEmotions"
    )


class CountEmotionsCountEmotions(BaseModel):
    count: Optional[Any]


CountEmotions.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import CollectionTypes, EntityState


class RemoveSkillsFromCollection(BaseModel):
    remove_skills_from_collection: Optional[
        "RemoveSkillsFromCollectionRemoveSkillsFromCollection"
    ] = Field(alias="removeSkillsFromCollection")


class RemoveSkillsFromCollectionRemoveSkillsFromCollection(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[CollectionTypes]
    contents: Optional[
        list[Optional["RemoveSkillsFromCollectionRemoveSkillsFromCollectionContents"]]
    ]


class RemoveSkillsFromCollectionRemoveSkillsFromCollectionContents(BaseModel):
    id: str
    name: str


RemoveSkillsFromCollection.model_rebuild()
RemoveSkillsFromCollectionRemoveSkillsFromCollection.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class UpdatePersona(BaseModel):
    update_persona: Optional["UpdatePersonaUpdatePersona"] = Field(
        alias="updatePersona"
    )


class UpdatePersonaUpdatePersona(BaseModel):
    id: str
    name: str
    state: EntityState
    identifier: Optional[str]
    platform: Optional[str]
    display_name: Optional[str] = Field(alias="displayName")
    timezone: Optional[str]
    role: Optional[str]


UpdatePersona.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ContentTypes,
    ConversationRoleTypes,
    EntityState,
    FileTypes,
    ImageProjectionTypes,
    ModelServiceTypes,
    OrientationTypes,
)


class DescribeImage(BaseModel):
    describe_image: Optional["DescribeImageDescribeImage"] = Field(
        alias="describeImage"
    )


class DescribeImageDescribeImage(BaseModel):
    role: ConversationRoleTypes
    author: Optional[str]
    message: Optional[str]
    citations: Optional[list[Optional["DescribeImageDescribeImageCitations"]]]
    tool_calls: Optional[list[Optional["DescribeImageDescribeImageToolCalls"]]] = Field(
        alias="toolCalls"
    )
    tokens: Optional[int]
    throughput: Optional[float]
    ttft: Optional[Any]
    completion_time: Optional[Any] = Field(alias="completionTime")
    timestamp: Optional[Any]
    model_service: Optional[ModelServiceTypes] = Field(alias="modelService")
    model: Optional[str]
    data: Optional[str]
    mime_type: Optional[str] = Field(alias="mimeType")
    tool_call_id: Optional[str] = Field(alias="toolCallId")
    tool_call_response: Optional[str] = Field(alias="toolCallResponse")
    artifacts: Optional[list[Optional["DescribeImageDescribeImageArtifacts"]]]
    thinking_content: Optional[str] = Field(alias="thinkingContent")
    thinking_signature: Optional[str] = Field(alias="thinkingSignature")


class DescribeImageDescribeImageCitations(BaseModel):
    content: Optional["DescribeImageDescribeImageCitationsContent"]
    index: Optional[int]
    text: str
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    page_number: Optional[int] = Field(alias="pageNumber")
    frame_number: Optional[int] = Field(alias="frameNumber")


class DescribeImageDescribeImageCitationsContent(BaseModel):
    id: str
    name: str
    state: EntityState
    original_date: Optional[Any] = Field(alias="originalDate")
    identifier: Optional[str]
    uri: Optional[Any]
    type: Optional[ContentTypes]
    file_type: Optional[FileTypes] = Field(alias="fileType")
    mime_type: Optional[str] = Field(alias="mimeType")
    format: Optional[str]
    format_name: Optional[str] = Field(alias="formatName")
    file_extension: Optional[str] = Field(alias="fileExtension")
    file_name: Optional[str] = Field(alias="fileName")
    file_size: Optional[Any] = Field(alias="fileSize")
    file_metadata: Optional[str] = Field(alias="fileMetadata")
    relative_folder_path: Optional[str] = Field(alias="relativeFolderPath")
    master_uri: Optional[Any] = Field(alias="masterUri")
    image_uri: Optional[Any] = Field(alias="imageUri")
    text_uri: Optional[Any] = Field(alias="textUri")
    audio_uri: Optional[Any] = Field(alias="audioUri")
    transcript_uri: Optional[Any] = Field(alias="transcriptUri")
    snapshots_uri: Optional[Any] = Field(alias="snapshotsUri")
    snapshot_count: Optional[int] = Field(alias="snapshotCount")
    summary: Optional[str]
    custom_summary: Optional[str] = Field(alias="customSummary")
    keywords: Optional[list[str]]
    bullets: Optional[list[str]]
    headlines: Optional[list[str]]
    posts: Optional[list[str]]
    chapters: Optional[list[str]]
    questions: Optional[list[str]]
    quotes: Optional[list[str]]
    video: Optional["DescribeImageDescribeImageCitationsContentVideo"]
    audio: Optional["DescribeImageDescribeImageCitationsContentAudio"]
    image: Optional["DescribeImageDescribeImageCitationsContentImage"]
    document: Optional["DescribeImageDescribeImageCitationsContentDocument"]


class DescribeImageDescribeImageCitationsContentVideo(BaseModel):
    width: Optional[int]
    height: Optional[int]
    duration: Optional[Any]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    title: Optional[str]
    description: Optional[str]
    keywords: Optional[list[Optional[str]]]
    author: Optional[str]


class DescribeImageDescribeImageCitationsContentAudio(BaseModel):
    keywords: Optional[list[Optional[str]]]
    author: Optional[str]
    series: Optional[str]
    episode: Optional[str]
    episode_type: Optional[str] = Field(alias="episodeType")
    season: Optional[str]
    publisher: Optional[str]
    copyright: Optional[str]
    genre: Optional[str]
    title: Optional[str]
    description: Optional[str]
    bitrate: Optional[int]
    channels: Optional[int]
    sample_rate: Optional[int] = Field(alias="sampleRate")
    bits_per_sample: Optional[int] = Field(alias="bitsPerSample")
    duration: Optional[Any]


class DescribeImageDescribeImageCitationsContentImage(BaseModel):
    width: Optional[int]
    height: Optional[int]
    resolution_x: Optional[int] = Field(alias="resolutionX")
    resolution_y: Optional[int] = Field(alias="resolutionY")
    bits_per_component: Optional[int] = Field(alias="bitsPerComponent")
    components: Optional[int]
    projection_type: Optional[ImageProjectionTypes] = Field(alias="projectionType")
    orientation: Optional[OrientationTypes]
    description: Optional[str]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    lens: Optional[str]
    focal_length: Optional[float] = Field(alias="focalLength")
    exposure_time: Optional[str] = Field(alias="exposureTime")
    f_number: Optional[str] = Field(alias="fNumber")
    iso: Optional[str]
    heading: Optional[float]
    pitch: Optional[float]


class DescribeImageDescribeImageCitationsContentDocument(BaseModel):
    title: Optional[str]
    subject: Optional[str]
    summary: Optional[str]
    author: Optional[str]
    last_modified_by: Optional[str] = Field(alias="lastModifiedBy")
    publisher: Optional[str]
    description: Optional[str]
    keywords: Optional[list[Optional[str]]]
    page_count: Optional[int] = Field(alias="pageCount")
    worksheet_count: Optional[int] = Field(alias="worksheetCount")
    slide_count: Optional[int] = Field(alias="slideCount")
    word_count: Optional[int] = Field(alias="wordCount")
    line_count: Optional[int] = Field(alias="lineCount")
    paragraph_count: Optional[int] = Field(alias="paragraphCount")
    is_encrypted: Optional[bool] = Field(alias="isEncrypted")
    has_digital_signature: Optional[bool] = Field(alias="hasDigitalSignature")


class DescribeImageDescribeImageToolCalls(BaseModel):
    id: str
    name: str
    arguments: str


class DescribeImageDescribeImageArtifacts(BaseModel):
    id: str
    name: str
    mime_type: Optional[str] = Field(alias="mimeType")
    uri: Optional[Any]


DescribeImage.model_rebuild()
DescribeImageDescribeImage.model_rebuild()
DescribeImageDescribeImageCitations.model_rebuild()
DescribeImageDescribeImageCitationsContent.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalTherapies(BaseModel):
    count_medical_therapies: Optional["CountMedicalTherapiesCountMedicalTherapies"] = (
        Field(alias="countMedicalTherapies")
    )


class CountMedicalTherapiesCountMedicalTherapies(BaseModel):
    count: Optional[Any]


CountMedicalTherapies.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DisableSkill(BaseModel):
    disable_skill: Optional["DisableSkillDisableSkill"] = Field(alias="disableSkill")


class DisableSkillDisableSkill(BaseModel):
    id: str
    state: EntityState


DisableSkill.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountSkills(BaseModel):
    count_skills: Optional["CountSkillsCountSkills"] = Field(alias="countSkills")


class CountSkillsCountSkills(BaseModel):
    count: Optional[Any]


CountSkills.model_rebuild()



# Generated by ariadne-codegen
# Source: https://data-scus.graphlit.io/api/v1/graphql

from enum import Enum


class FactCategory(str, Enum):
    RELATIONSHIP = "RELATIONSHIP"
    EVENT = "EVENT"
    FACT = "FACT"
    PREFERENCE = "PREFERENCE"
    CHANGE = "CHANGE"
    QUANTITATIVE = "QUANTITATIVE"
    GOAL = "GOAL"
    CAPABILITY = "CAPABILITY"
    CONSTRAINT = "CONSTRAINT"
    DECISION = "DECISION"
    APPROVAL = "APPROVAL"
    EXCEPTION = "EXCEPTION"
    ESCALATION = "ESCALATION"
    OVERRIDE = "OVERRIDE"
    PRECEDENT = "PRECEDENT"
    RATIONALE = "RATIONALE"
    COMMITMENT = "COMMITMENT"
    DELEGATION = "DELEGATION"


class TwitterAuthenticationTypes(str, Enum):
    TOKEN = "TOKEN"
    CONNECTOR = "CONNECTOR"


class AzureOpenAIModels(str, Enum):
    GPT35_TURBO_16K = "GPT35_TURBO_16K"
    GPT4 = "GPT4"
    GPT4_TURBO_128K = "GPT4_TURBO_128K"
    CUSTOM = "CUSTOM"


class TwelveLabsModels(str, Enum):
    MARENGO_3_0 = "MARENGO_3_0"


class LinkTypes(str, Enum):
    DROPBOX = "DROPBOX"
    TYPE_FORM = "TYPE_FORM"
    AIRTABLE = "AIRTABLE"
    MICROSOFT_TEAMS = "MICROSOFT_TEAMS"
    DISCORD = "DISCORD"
    APPLE = "APPLE"
    SLACK = "SLACK"
    ANGEL_LIST = "ANGEL_LIST"
    CRUNCHBASE = "CRUNCHBASE"
    LINKED_IN = "LINKED_IN"
    DIFFBOT = "DIFFBOT"
    REDDIT = "REDDIT"
    GOOGLE = "GOOGLE"
    IFTTT = "IFTTT"
    FACEBOOK = "FACEBOOK"
    WIKIPEDIA = "WIKIPEDIA"
    WIKIMEDIA = "WIKIMEDIA"
    WIKIDATA = "WIKIDATA"
    INSTAGRAM = "INSTAGRAM"
    TWITCH = "TWITCH"
    POCKET_CASTS = "POCKET_CASTS"
    SPOTIFY = "SPOTIFY"
    TUNE_IN = "TUNE_IN"
    STITCHER = "STITCHER"
    ANCHOR_FM = "ANCHOR_FM"
    TRANSISTOR_FM = "TRANSISTOR_FM"
    I_TUNES = "I_TUNES"
    PANDORA = "PANDORA"
    SOUND_CLOUD = "SOUND_CLOUD"
    BANDCAMP = "BANDCAMP"
    TIK_TOK = "TIK_TOK"
    YOU_TUBE = "YOU_TUBE"
    TWITTER = "TWITTER"
    X = "X"
    MEDIUM = "MEDIUM"
    NOTION = "NOTION"
    HUB_SPOT = "HUB_SPOT"
    LINEAR = "LINEAR"
    GIT_HUB = "GIT_HUB"
    GIT_HUB_PAGES = "GIT_HUB_PAGES"
    RSS = "RSS"
    EMAIL = "EMAIL"
    MEDIA = "MEDIA"
    WEB = "WEB"
    FILE = "FILE"


class CollectionTypes(str, Enum):
    COLLECTION = "COLLECTION"
    CONVERSATION = "CONVERSATION"
    THREAD = "THREAD"
    SERIES = "SERIES"
    FOLDER = "FOLDER"


class MedicalProcedureFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class SlackAuthenticationTypes(str, Enum):
    TOKEN = "TOKEN"
    CONNECTOR = "CONNECTOR"


class FeedTypes(str, Enum):
    INTERCOM = "INTERCOM"
    ZENDESK = "ZENDESK"
    NOTION = "NOTION"
    TWITTER = "TWITTER"
    SLACK = "SLACK"
    MICROSOFT_TEAMS = "MICROSOFT_TEAMS"
    DISCORD = "DISCORD"
    REDDIT = "REDDIT"
    LINKED_IN = "LINKED_IN"
    WEB = "WEB"
    RSS = "RSS"
    SITE = "SITE"
    YOU_TUBE = "YOU_TUBE"
    EMAIL = "EMAIL"
    ISSUE = "ISSUE"
    INITIATIVE = "INITIATIVE"
    PULL_REQUEST = "PULL_REQUEST"
    COMMIT = "COMMIT"
    SEARCH = "SEARCH"
    CALENDAR = "CALENDAR"
    CRM = "CRM"
    RESEARCH = "RESEARCH"
    ENTITY = "ENTITY"
    ATTIO = "ATTIO"
    SALESFORCE = "SALESFORCE"
    HUB_SPOT = "HUB_SPOT"
    HUB_SPOT_CONVERSATIONS = "HUB_SPOT_CONVERSATIONS"
    CONFLUENCE = "CONFLUENCE"
    MEETING = "MEETING"
    HRIS = "HRIS"
    INTERCOM_CONVERSATIONS = "INTERCOM_CONVERSATIONS"
    PRODUCTLANE = "PRODUCTLANE"


class H3ResolutionTypes(str, Enum):
    R0 = "R0"
    R1 = "R1"
    R2 = "R2"
    R3 = "R3"
    R4 = "R4"
    R5 = "R5"
    R6 = "R6"
    R7 = "R7"
    R8 = "R8"
    R9 = "R9"
    R10 = "R10"
    R11 = "R11"
    R12 = "R12"
    R13 = "R13"
    R14 = "R14"
    R15 = "R15"


class DropboxAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class GoogleDriveAuthenticationTypes(str, Enum):
    SERVICE_ACCOUNT = "SERVICE_ACCOUNT"
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class AnthropicEffortLevels(str, Enum):
    LOW = "LOW"
    MEDIUM = "MEDIUM"
    HIGH = "HIGH"
    MAX = "MAX"


class LinearAuthenticationTypes(str, Enum):
    API_KEY = "API_KEY"
    O_AUTH = "O_AUTH"
    CONNECTOR = "CONNECTOR"


class RerankingModelServiceTypes(str, Enum):
    COHERE = "COHERE"
    JINA = "JINA"
    VOYAGE = "VOYAGE"


class AttioAuthenticationTypes(str, Enum):
    API_KEY = "API_KEY"
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class PlaceFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class SourceTypes(str, Enum):
    CONTENT = "CONTENT"
    CONVERSATION = "CONVERSATION"
    PERSONA = "PERSONA"


class InvestmentFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class IntercomAuthenticationTypes(str, Enum):
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class MedicalDrugFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class RetrievalStrategyTypes(str, Enum):
    CONTENT = "CONTENT"
    CHUNK = "CHUNK"
    SECTION = "SECTION"


class MedicalGuidelineFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class OpenAIVisionDetailLevels(str, Enum):
    HIGH = "HIGH"
    LOW = "LOW"


class ContentPublishingFormats(str, Enum):
    PNG = "PNG"
    JPEG = "JPEG"
    WEBP = "WEBP"
    MP3 = "MP3"
    MP4 = "MP4"
    TEXT = "TEXT"
    MARKDOWN = "MARKDOWN"
    HTML = "HTML"
    SVG = "SVG"


class AzureDocumentIntelligenceModels(str, Enum):
    READ_OCR = "READ_OCR"
    LAYOUT = "LAYOUT"
    INVOICE = "INVOICE"
    RECEIPT = "RECEIPT"
    IDENTIFICATION_DOCUMENT = "IDENTIFICATION_DOCUMENT"
    US_HEALTH_INSURANCE_CARD = "US_HEALTH_INSURANCE_CARD"
    US_TAX_FORM = "US_TAX_FORM"
    US_TAX_FORM_W2 = "US_TAX_FORM_W2"
    US_TAX_FORM1098 = "US_TAX_FORM1098"
    US_TAX_FORM1098_E = "US_TAX_FORM1098_E"
    US_TAX_FORM1098_T = "US_TAX_FORM1098_T"
    US_TAX_FORM1099 = "US_TAX_FORM1099"
    US_MARRIAGE_CERTIFICATE = "US_MARRIAGE_CERTIFICATE"
    US_MORTGAGE1003 = "US_MORTGAGE1003"
    US_MORTGAGE1008 = "US_MORTGAGE1008"
    US_MORTGAGE_DISCLOSURE = "US_MORTGAGE_DISCLOSURE"
    CREDIT_CARD = "CREDIT_CARD"
    US_PAY_STUB = "US_PAY_STUB"
    US_BANK_CHECK = "US_BANK_CHECK"
    US_BANK_STATEMENT = "US_BANK_STATEMENT"


class GitHubAuthenticationTypes(str, Enum):
    PERSONAL_ACCESS_TOKEN = "PERSONAL_ACCESS_TOKEN"
    O_AUTH = "O_AUTH"
    CONNECTOR = "CONNECTOR"


class GoogleEmailAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class JinaModels(str, Enum):
    CLIP_IMAGE = "CLIP_IMAGE"
    EMBED = "EMBED"
    EMBED_3_0 = "EMBED_3_0"
    EMBED_4_0 = "EMBED_4_0"
    CUSTOM = "CUSTOM"


class OneDriveAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class GraphStrategyTypes(str, Enum):
    EXTRACT_ENTITIES_FILTER = "EXTRACT_ENTITIES_FILTER"
    EXTRACT_ENTITIES_GRAPH = "EXTRACT_ENTITIES_GRAPH"
    NONE = "NONE"


class MicrosoftTeamsAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class AuthenticationServiceTypes(str, Enum):
    AUTH0 = "AUTH0"
    MICROSOFT_GRAPH = "MICROSOFT_GRAPH"
    CLERK = "CLERK"
    GOOGLE = "GOOGLE"
    O_AUTH = "O_AUTH"
    ARCADE = "ARCADE"
    TOKEN = "TOKEN"
    API_KEY = "API_KEY"


class RevisionStrategyTypes(str, Enum):
    REVISE = "REVISE"
    CUSTOM = "CUSTOM"
    NONE = "NONE"


class DeepseekModels(str, Enum):
    REASONER = "REASONER"
    CHAT = "CHAT"
    CODER = "CODER"
    CUSTOM = "CUSTOM"


class AnthropicModels(str, Enum):
    CLAUDE_2 = "CLAUDE_2"
    CLAUDE_2_0 = "CLAUDE_2_0"
    CLAUDE_2_1 = "CLAUDE_2_1"
    CLAUDE_INSTANT_1 = "CLAUDE_INSTANT_1"
    CLAUDE_INSTANT_1_2 = "CLAUDE_INSTANT_1_2"
    CLAUDE_3_OPUS = "CLAUDE_3_OPUS"
    CLAUDE_3_OPUS_20240229 = "CLAUDE_3_OPUS_20240229"
    CLAUDE_3_SONNET = "CLAUDE_3_SONNET"
    CLAUDE_3_SONNET_20240229 = "CLAUDE_3_SONNET_20240229"
    CLAUDE_3_HAIKU = "CLAUDE_3_HAIKU"
    CLAUDE_3_HAIKU_20240307 = "CLAUDE_3_HAIKU_20240307"
    CLAUDE_3_5_SONNET = "CLAUDE_3_5_SONNET"
    CLAUDE_3_5_SONNET_20241022 = "CLAUDE_3_5_SONNET_20241022"
    CLAUDE_3_5_SONNET_20240620 = "CLAUDE_3_5_SONNET_20240620"
    CLAUDE_3_5_HAIKU = "CLAUDE_3_5_HAIKU"
    CLAUDE_3_5_HAIKU_20241022 = "CLAUDE_3_5_HAIKU_20241022"
    CLAUDE_3_7_SONNET = "CLAUDE_3_7_SONNET"
    CLAUDE_3_7_SONNET_20250219 = "CLAUDE_3_7_SONNET_20250219"
    CLAUDE_4_SONNET = "CLAUDE_4_SONNET"
    CLAUDE_4_SONNET_20250514 = "CLAUDE_4_SONNET_20250514"
    CLAUDE_4_5_SONNET = "CLAUDE_4_5_SONNET"
    CLAUDE_4_5_SONNET_20250929 = "CLAUDE_4_5_SONNET_20250929"
    CLAUDE_4_6_SONNET = "CLAUDE_4_6_SONNET"
    CLAUDE_4_6_SONNET_20260217 = "CLAUDE_4_6_SONNET_20260217"
    CLAUDE_4_6_SONNET_1_M = "CLAUDE_4_6_SONNET_1_M"
    CLAUDE_4_6_SONNET_1_M_20260217 = "CLAUDE_4_6_SONNET_1_M_20260217"
    CLAUDE_4_5_OPUS = "CLAUDE_4_5_OPUS"
    CLAUDE_4_5_OPUS_20251101 = "CLAUDE_4_5_OPUS_20251101"
    CLAUDE_4_6_OPUS = "CLAUDE_4_6_OPUS"
    CLAUDE_4_6_OPUS_20260205 = "CLAUDE_4_6_OPUS_20260205"
    CLAUDE_4_6_OPUS_1_M = "CLAUDE_4_6_OPUS_1_M"
    CLAUDE_4_6_OPUS_1_M_20260205 = "CLAUDE_4_6_OPUS_1_M_20260205"
    CLAUDE_4_OPUS = "CLAUDE_4_OPUS"
    CLAUDE_4_OPUS_20250514 = "CLAUDE_4_OPUS_20250514"
    CLAUDE_4_1_OPUS = "CLAUDE_4_1_OPUS"
    CLAUDE_4_1_OPUS_20250805 = "CLAUDE_4_1_OPUS_20250805"
    CLAUDE_4_5_HAIKU = "CLAUDE_4_5_HAIKU"
    CLAUDE_4_5_HAIKU_20251001 = "CLAUDE_4_5_HAIKU_20251001"
    CUSTOM = "CUSTOM"


class TwelveLabsSegmentationMethods(str, Enum):
    DYNAMIC = "DYNAMIC"
    FIXED = "FIXED"


class TimedPolicyRecurrenceTypes(str, Enum):
    ONCE = "ONCE"
    REPEAT = "REPEAT"
    MONITOR = "MONITOR"


class ElevenLabsModels(str, Enum):
    MULTILINGUAL_V1 = "MULTILINGUAL_V1"
    MULTILINGUAL_V2 = "MULTILINGUAL_V2"
    ENGLISH_V1 = "ENGLISH_V1"
    FLASH_V2 = "FLASH_V2"
    FLASH_V2_5 = "FLASH_V2_5"
    TURBO_V2 = "TURBO_V2"
    TURBO_V2_5 = "TURBO_V2_5"


class BlobListingTypes(str, Enum):
    PAST = "PAST"
    NEW = "NEW"


class AttioFeedAuthenticationTypes(str, Enum):
    API_KEY = "API_KEY"
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class GroqModels(str, Enum):
    LLAMA_4_MAVERICK_17B = "LLAMA_4_MAVERICK_17B"
    LLAMA_4_SCOUT_17B = "LLAMA_4_SCOUT_17B"
    DEEPSEEK_R1_LLAMA_70B_PREVIEW = "DEEPSEEK_R1_LLAMA_70B_PREVIEW"
    MIXTRAL_8X7B_INSTRUCT = "MIXTRAL_8X7B_INSTRUCT"
    LLAMA_3_3_70B = "LLAMA_3_3_70B"
    LLAMA_3_2_90B_VISION_PREVIEW = "LLAMA_3_2_90B_VISION_PREVIEW"
    LLAMA_3_2_11B_VISION_PREVIEW = "LLAMA_3_2_11B_VISION_PREVIEW"
    LLAMA_3_2_3B_PREVIEW = "LLAMA_3_2_3B_PREVIEW"
    LLAMA_3_2_1B_PREVIEW = "LLAMA_3_2_1B_PREVIEW"
    LLAMA_3_1_8B = "LLAMA_3_1_8B"
    LLAMA_3_70B = "LLAMA_3_70B"
    LLAMA_3_8B = "LLAMA_3_8B"
    KIMI_K2_32B = "KIMI_K2_32B"
    QWEN_3_32B = "QWEN_3_32B"
    CUSTOM = "CUSTOM"


class OrderByTypes(str, Enum):
    NAME = "NAME"
    CREATION_DATE = "CREATION_DATE"
    ORIGINAL_DATE = "ORIGINAL_DATE"
    RELEVANCE = "RELEVANCE"


class OpenAIVideoModels(str, Enum):
    SORA_2 = "SORA_2"
    SORA_2_PRO = "SORA_2_PRO"
    CUSTOM = "CUSTOM"


class ConnectorTypes(str, Enum):
    INTEGRATION = "INTEGRATION"
    AUTHENTICATION = "AUTHENTICATION"
    SITE = "SITE"


class ModelTypes(str, Enum):
    COMPLETION = "COMPLETION"
    TEXT_EMBEDDING = "TEXT_EMBEDDING"
    IMAGE_EMBEDDING = "IMAGE_EMBEDDING"
    MULTIMODAL_EMBEDDING = "MULTIMODAL_EMBEDDING"
    RERANKING = "RERANKING"


class AssemblyAIModels(str, Enum):
    BEST = "BEST"
    NANO = "NANO"


class FileTypes(str, Enum):
    VIDEO = "VIDEO"
    AUDIO = "AUDIO"
    IMAGE = "IMAGE"
    ANIMATION = "ANIMATION"
    DOCUMENT = "DOCUMENT"
    EMAIL = "EMAIL"
    CODE = "CODE"
    DATA = "DATA"
    PACKAGE = "PACKAGE"
    SHAPE = "SHAPE"
    POINT_CLOUD = "POINT_CLOUD"
    GEOMETRY = "GEOMETRY"
    DRAWING = "DRAWING"
    SUBTITLES = "SUBTITLES"
    MANIFEST = "MANIFEST"
    UNKNOWN = "UNKNOWN"


class DeepgramModels(str, Enum):
    NOVA3_MEDICAL = "NOVA3_MEDICAL"
    NOVA3 = "NOVA3"
    NOVA2 = "NOVA2"
    NOVA2_MEETING = "NOVA2_MEETING"
    NOVA2_PHONECALL = "NOVA2_PHONECALL"
    NOVA2_VOICEMAIL = "NOVA2_VOICEMAIL"
    NOVA2_FINANCE = "NOVA2_FINANCE"
    NOVA2_CONVERSATIONAL_AI = "NOVA2_CONVERSATIONAL_AI"
    NOVA2_VIDEO = "NOVA2_VIDEO"
    NOVA2_MEDICAL = "NOVA2_MEDICAL"
    NOVA2_DRIVETHRU = "NOVA2_DRIVETHRU"
    NOVA2_AUTOMOTIVE = "NOVA2_AUTOMOTIVE"
    WHISPER_TINY = "WHISPER_TINY"
    WHISPER_SMALL = "WHISPER_SMALL"
    WHISPER_BASE = "WHISPER_BASE"
    WHISPER_MEDIUM = "WHISPER_MEDIUM"
    WHISPER_LARGE = "WHISPER_LARGE"


class MedicalContraindicationFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class MCPServerTypes(str, Enum):
    REMOTE_SSE = "REMOTE_SSE"
    REMOTE_HTTP = "REMOTE_HTTP"
    LOCAL_NPX = "LOCAL_NPX"


class MailPriority(str, Enum):
    NORMAL = "NORMAL"
    LOW = "LOW"
    HIGH = "HIGH"


class ConversationTypes(str, Enum):
    CONTENT = "CONTENT"
    AGENT = "AGENT"


class OpenAIImageModels(str, Enum):
    GPT_IMAGE_1 = "GPT_IMAGE_1"
    GPT_IMAGE_1_MINI = "GPT_IMAGE_1_MINI"
    GPT_IMAGE_1_5 = "GPT_IMAGE_1_5"
    CUSTOM = "CUSTOM"


class SummarizationTypes(str, Enum):
    SUMMARY = "SUMMARY"
    KEYWORDS = "KEYWORDS"
    BULLETS = "BULLETS"
    HEADLINES = "HEADLINES"
    POSTS = "POSTS"
    CHAPTERS = "CHAPTERS"
    QUESTIONS = "QUESTIONS"
    QUOTES = "QUOTES"
    GEOTAG = "GEOTAG"
    CUSTOM = "CUSTOM"


class OrderDirectionTypes(str, Enum):
    ASCENDING = "ASCENDING"
    DESCENDING = "DESCENDING"


class CalendarEventVisibility(str, Enum):
    DEFAULT = "DEFAULT"
    PUBLIC = "PUBLIC"
    PRIVATE = "PRIVATE"
    CONFIDENTIAL = "CONFIDENTIAL"


class MedicalDeviceFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class OperationTypes(str, Enum):
    QUERY = "QUERY"
    MUTATION = "MUTATION"


class SpecificationTypes(str, Enum):
    COMPLETION = "COMPLETION"
    AGENTIC = "AGENTIC"
    TEXT_EMBEDDING = "TEXT_EMBEDDING"
    IMAGE_EMBEDDING = "IMAGE_EMBEDDING"
    EXTRACTION = "EXTRACTION"
    CLASSIFICATION = "CLASSIFICATION"
    SUMMARIZATION = "SUMMARIZATION"
    PREPARATION = "PREPARATION"
    MULTIMODAL_EMBEDDING = "MULTIMODAL_EMBEDDING"


class CalendarEventStatus(str, Enum):
    CONFIRMED = "CONFIRMED"
    TENTATIVE = "TENTATIVE"
    CANCELLED = "CANCELLED"


class MetadataTypes(str, Enum):
    CONTENT = "CONTENT"
    CONVERSATION = "CONVERSATION"


class VoyageModels(str, Enum):
    VOYAGE = "VOYAGE"
    VOYAGE_3_5 = "VOYAGE_3_5"
    VOYAGE_3_5_LITE = "VOYAGE_3_5_LITE"
    VOYAGE_3_0_LARGE = "VOYAGE_3_0_LARGE"
    VOYAGE_3_0 = "VOYAGE_3_0"
    VOYAGE_LITE_3_0 = "VOYAGE_LITE_3_0"
    VOYAGE_CODE_3_0 = "VOYAGE_CODE_3_0"
    VOYAGE_FINANCE_2_0 = "VOYAGE_FINANCE_2_0"
    VOYAGE_MULTILINGUAL_2_0 = "VOYAGE_MULTILINGUAL_2_0"
    VOYAGE_LAW_2_0 = "VOYAGE_LAW_2_0"
    VOYAGE_CODE_2_0 = "VOYAGE_CODE_2_0"
    CUSTOM = "CUSTOM"


class AlertTypes(str, Enum):
    PROMPT = "PROMPT"


class MeetingContentTypes(str, Enum):
    TRANSCRIPT = "TRANSCRIPT"
    RECORDING = "RECORDING"
    PREFERRED = "PREFERRED"


class SalesforceAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class ContentTypes(str, Enum):
    FILE = "FILE"
    PAGE = "PAGE"
    MESSAGE = "MESSAGE"
    TEXT = "TEXT"
    POST = "POST"
    EMAIL = "EMAIL"
    EVENT = "EVENT"
    ISSUE = "ISSUE"
    INITIATIVE = "INITIATIVE"
    PULL_REQUEST = "PULL_REQUEST"
    COMMIT = "COMMIT"
    MEMORY = "MEMORY"
    TRANSCRIPT = "TRANSCRIPT"


class EntityExtractionServiceTypes(str, Enum):
    MODEL_TEXT = "MODEL_TEXT"
    MODEL_IMAGE = "MODEL_IMAGE"
    OPEN_AI_IMAGE = "OPEN_AI_IMAGE"
    AZURE_COGNITIVE_SERVICES_IMAGE = "AZURE_COGNITIVE_SERVICES_IMAGE"
    AZURE_COGNITIVE_SERVICES_TEXT = "AZURE_COGNITIVE_SERVICES_TEXT"
    HUME_EMOTION = "HUME_EMOTION"


class TwitterListingTypes(str, Enum):
    POSTS = "POSTS"
    MENTIONS = "MENTIONS"
    RECENT_SEARCH = "RECENT_SEARCH"


class RenditionTypes(str, Enum):
    CONTENT = "CONTENT"


class ConversationRoleTypes(str, Enum):
    SYSTEM = "SYSTEM"
    ASSISTANT = "ASSISTANT"
    USER = "USER"
    TOOL = "TOOL"


class GoogleCalendarAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class MailImportance(str, Enum):
    NORMAL = "NORMAL"
    LOW = "LOW"
    HIGH = "HIGH"


class SalesforceIssueAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class FeedListingTypes(str, Enum):
    PAST = "PAST"
    NEW = "NEW"


class HubSpotAuthenticationTypes(str, Enum):
    USER = "USER"
    PRIVATE_APP = "PRIVATE_APP"
    CONNECTOR = "CONNECTOR"


class HubSpotIssueAuthenticationTypes(str, Enum):
    USER = "USER"
    PRIVATE_APP = "PRIVATE_APP"
    CONNECTOR = "CONNECTOR"


class NotionAuthenticationTypes(str, Enum):
    TOKEN = "TOKEN"
    CONNECTOR = "CONNECTOR"


class SalesforceFeedAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class GoogleVideoModels(str, Enum):
    VEO_3 = "VEO_3"
    VEO_3_FAST = "VEO_3_FAST"
    VEO_3_1_PREVIEW = "VEO_3_1_PREVIEW"
    VEO_3_1_FAST_PREVIEW = "VEO_3_1_FAST_PREVIEW"
    CUSTOM = "CUSTOM"


class OpenAIImageSizeTypes(str, Enum):
    SQUARE = "SQUARE"
    LANDSCAPE = "LANDSCAPE"
    PORTRAIT = "PORTRAIT"
    AUTO = "AUTO"


class MedicalIndicationFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class ViewTypes(str, Enum):
    CONTENT = "CONTENT"


class RepoFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class GustoAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class BedrockModels(str, Enum):
    LLAMA_4_MAVERICK_17B = "LLAMA_4_MAVERICK_17B"
    LLAMA_4_SCOUT_17B = "LLAMA_4_SCOUT_17B"
    CLAUDE_3_7_SONNET = "CLAUDE_3_7_SONNET"
    NOVA_PREMIER = "NOVA_PREMIER"
    NOVA_PRO = "NOVA_PRO"
    CUSTOM = "CUSTOM"


class AzureDocumentIntelligenceVersions(str, Enum):
    V2023_07_31 = "V2023_07_31"
    V2024_02_29_PREVIEW = "V2024_02_29_PREVIEW"
    V2024_07_31_PREVIEW = "V2024_07_31_PREVIEW"
    V2024_11_30 = "V2024_11_30"


class ArcadeProviders(str, Enum):
    GOOGLE = "GOOGLE"
    GIT_HUB = "GIT_HUB"
    MICROSOFT = "MICROSOFT"


class LabelFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class ContentFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"
    ORIGINAL_DATE = "ORIGINAL_DATE"
    OBSERVABLE = "OBSERVABLE"
    CONTENT_TYPE = "CONTENT_TYPE"
    FILE_TYPE = "FILE_TYPE"
    FORMAT = "FORMAT"
    FORMAT_NAME = "FORMAT_NAME"
    FILE_EXTENSION = "FILE_EXTENSION"
    FILE_SIZE = "FILE_SIZE"
    DEVICE_TYPE = "DEVICE_TYPE"
    IMAGE_MAKE = "IMAGE_MAKE"
    IMAGE_MODEL = "IMAGE_MODEL"
    IMAGE_SOFTWARE = "IMAGE_SOFTWARE"
    AUDIO_AUTHOR = "AUDIO_AUTHOR"
    AUDIO_SERIES = "AUDIO_SERIES"
    AUDIO_PUBLISHER = "AUDIO_PUBLISHER"
    VIDEO_MAKE = "VIDEO_MAKE"
    VIDEO_MODEL = "VIDEO_MODEL"
    VIDEO_SOFTWARE = "VIDEO_SOFTWARE"
    DOCUMENT_AUTHOR = "DOCUMENT_AUTHOR"
    DOCUMENT_PUBLISHER = "DOCUMENT_PUBLISHER"
    DOCUMENT_IS_ENCRYPTED = "DOCUMENT_IS_ENCRYPTED"
    DOCUMENT_HAS_DIGITAL_SIGNATURE = "DOCUMENT_HAS_DIGITAL_SIGNATURE"
    EMAIL_PRIORITY = "EMAIL_PRIORITY"
    EMAIL_SENSITIVITY = "EMAIL_SENSITIVITY"
    ISSUE_PROJECT = "ISSUE_PROJECT"
    ISSUE_TEAM = "ISSUE_TEAM"
    ISSUE_PRIORITY = "ISSUE_PRIORITY"
    ISSUE_STATUS = "ISSUE_STATUS"
    ISSUE_TYPE = "ISSUE_TYPE"


class RegexSourceTypes(str, Enum):
    MARKDOWN = "MARKDOWN"
    METADATA = "METADATA"


class OccurrenceTypes(str, Enum):
    IMAGE = "IMAGE"
    TIME = "TIME"
    TEXT = "TEXT"
    TURN = "TURN"


class InvestmentFundFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class EntityOwners(str, Enum):
    SYSTEM = "SYSTEM"
    PROJECT = "PROJECT"


class ElevenLabsScribeModels(str, Enum):
    SCRIBE_V1 = "SCRIBE_V1"
    SCRIBE_V2 = "SCRIBE_V2"


class EmailListingTypes(str, Enum):
    PAST = "PAST"
    NEW = "NEW"


class BambooHRAuthenticationTypes(str, Enum):
    API_KEY = "API_KEY"


class ResourceConnectorTypes(str, Enum):
    AMAZON = "AMAZON"
    AZURE = "AZURE"
    GOOGLE = "GOOGLE"


class DistributionServiceTypes(str, Enum):
    NOTION = "NOTION"
    GOOGLE_DRIVE = "GOOGLE_DRIVE"
    ONE_DRIVE = "ONE_DRIVE"
    CONFLUENCE = "CONFLUENCE"
    SLACK = "SLACK"
    GMAIL = "GMAIL"
    MICROSOFT_OUTLOOK = "MICROSOFT_OUTLOOK"
    HUB_SPOT = "HUB_SPOT"
    SALESFORCE = "SALESFORCE"
    ATTIO = "ATTIO"
    GOOGLE_CALENDAR = "GOOGLE_CALENDAR"
    MICROSOFT_CALENDAR = "MICROSOFT_CALENDAR"
    LINEAR = "LINEAR"
    JIRA = "JIRA"
    GOOGLE_DOCS = "GOOGLE_DOCS"
    MICROSOFT_WORD = "MICROSOFT_WORD"
    SHARE_POINT = "SHARE_POINT"
    DISCORD = "DISCORD"
    MICROSOFT_TEAMS = "MICROSOFT_TEAMS"
    TWITTER = "TWITTER"
    GIT_HUB = "GIT_HUB"
    ATTIO_TASKS = "ATTIO_TASKS"


class ReductoExtractionModes(str, Enum):
    OCR = "OCR"
    METADATA = "METADATA"
    HYBRID = "HYBRID"


class MedicalConditionFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class EntityState(str, Enum):
    INITIALIZED = "INITIALIZED"
    RESTARTED = "RESTARTED"
    CREATED = "CREATED"
    INGESTED = "INGESTED"
    INDEXED = "INDEXED"
    PREPARED = "PREPARED"
    SANITIZED = "SANITIZED"
    EXTRACTED = "EXTRACTED"
    ENRICHED = "ENRICHED"
    CLASSIFIED = "CLASSIFIED"
    CHANGED = "CHANGED"
    ARCHIVED = "ARCHIVED"
    APPROVED = "APPROVED"
    REJECTED = "REJECTED"
    PENDING = "PENDING"
    QUEUED = "QUEUED"
    OPENED = "OPENED"
    CLOSED = "CLOSED"
    FINISHED = "FINISHED"
    PAUSED = "PAUSED"
    RUNNING = "RUNNING"
    SUBSCRIBED = "SUBSCRIBED"
    ERRORED = "ERRORED"
    ENABLED = "ENABLED"
    LIMITED = "LIMITED"
    RESOLVED = "RESOLVED"
    DISABLED = "DISABLED"
    DELETED = "DELETED"


class GitHubPullRequestAuthenticationTypes(str, Enum):
    PERSONAL_ACCESS_TOKEN = "PERSONAL_ACCESS_TOKEN"
    O_AUTH = "O_AUTH"
    CONNECTOR = "CONNECTOR"


class TextRoles(str, Enum):
    PAGE_HEADER = "PAGE_HEADER"
    PAGE_FOOTER = "PAGE_FOOTER"
    PAGE_NUMBER = "PAGE_NUMBER"
    TITLE = "TITLE"
    SECTION_HEADING = "SECTION_HEADING"
    FOOTNOTE = "FOOTNOTE"
    CODE = "CODE"
    LIST_ITEM = "LIST_ITEM"
    HEADING1 = "HEADING1"
    HEADING2 = "HEADING2"
    HEADING3 = "HEADING3"
    HEADING4 = "HEADING4"
    HEADING5 = "HEADING5"
    HEADING6 = "HEADING6"
    TABLE_COLUMN_HEADER = "TABLE_COLUMN_HEADER"
    TABLE_ROW_HEADER = "TABLE_ROW_HEADER"
    TABLE_CORNER_HEADER = "TABLE_CORNER_HEADER"
    TABLE_CELL = "TABLE_CELL"
    TABLE_CAPTION = "TABLE_CAPTION"
    TABLE_HEADER = "TABLE_HEADER"
    TABLE = "TABLE"
    IMAGE = "IMAGE"
    IMAGE_CAPTION = "IMAGE_CAPTION"
    FIGURE = "FIGURE"
    FIGURE_CAPTION = "FIGURE_CAPTION"
    BUTTON = "BUTTON"
    DIAGRAM = "DIAGRAM"
    DIAGRAM_CAPTION = "DIAGRAM_CAPTION"
    WATERMARK = "WATERMARK"
    EQUATION = "EQUATION"
    PARAGRAPH = "PARAGRAPH"
    CHECKBOX = "CHECKBOX"
    RADIO_BUTTON = "RADIO_BUTTON"
    COLUMN_HEADER = "COLUMN_HEADER"
    ROW_HEADER = "ROW_HEADER"
    CORNER_HEADER = "CORNER_HEADER"


class YouTubeTypes(str, Enum):
    VIDEO = "VIDEO"
    VIDEOS = "VIDEOS"
    PLAYLIST = "PLAYLIST"
    CHANNEL = "CHANNEL"


class NotionTypes(str, Enum):
    PAGE = "PAGE"
    DATABASE = "DATABASE"


class PromptStrategyTypes(str, Enum):
    OPTIMIZE_SEARCH = "OPTIMIZE_SEARCH"
    REWRITE = "REWRITE"
    NONE = "NONE"


class ReductoOcrModes(str, Enum):
    STANDARD = "STANDARD"
    AGENTIC = "AGENTIC"


class ConfluenceTypes(str, Enum):
    SPACE = "SPACE"
    PAGE = "PAGE"


class GoogleImageAspectRatioTypes(str, Enum):
    SQUARE_1X1 = "SQUARE_1X1"
    PORTRAIT_1X4 = "PORTRAIT_1X4"
    PORTRAIT_1X8 = "PORTRAIT_1X8"
    PORTRAIT_2X3 = "PORTRAIT_2X3"
    LANDSCAPE_3X2 = "LANDSCAPE_3X2"
    PORTRAIT_3X4 = "PORTRAIT_3X4"
    LANDSCAPE_4X1 = "LANDSCAPE_4X1"
    LANDSCAPE_4X3 = "LANDSCAPE_4X3"
    PORTRAIT_4X5 = "PORTRAIT_4X5"
    LANDSCAPE_5X4 = "LANDSCAPE_5X4"
    LANDSCAPE_8X1 = "LANDSCAPE_8X1"
    PORTRAIT_9X16 = "PORTRAIT_9X16"
    LANDSCAPE_16X9 = "LANDSCAPE_16X9"
    LANDSCAPE_21X9 = "LANDSCAPE_21X9"


class EmbeddingTypes(str, Enum):
    TEXT = "TEXT"
    IMAGE = "IMAGE"
    AUDIO = "AUDIO"
    VIDEO = "VIDEO"
    MULTIMODAL = "MULTIMODAL"


class MedicalTestFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class ReductoOcrSystems(str, Enum):
    HIGHRES = "HIGHRES"
    MULTILINGUAL = "MULTILINGUAL"
    COMBINED = "COMBINED"


class SoftwareFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class MailSensitivity(str, Enum):
    NONE = "NONE"
    NORMAL = "NORMAL"
    PERSONAL = "PERSONAL"
    PRIVATE = "PRIVATE"
    COMPANY_CONFIDENTIAL = "COMPANY_CONFIDENTIAL"


class MedicalStudyFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class SdkTypes(str, Enum):
    DOTNET = "DOTNET"
    PYTHON = "PYTHON"
    NODE_JS = "NODE_JS"


class GoogleThinkingLevels(str, Enum):
    MINIMAL = "MINIMAL"
    LOW = "LOW"
    MEDIUM = "MEDIUM"
    HIGH = "HIGH"


class SearchTypes(str, Enum):
    KEYWORD = "KEYWORD"
    VECTOR = "VECTOR"
    HYBRID = "HYBRID"


class MedicalTherapyFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class FacetValueTypes(str, Enum):
    VALUE = "VALUE"
    RANGE = "RANGE"
    OBJECT = "OBJECT"


class ZendeskIssueAuthenticationTypes(str, Enum):
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class ReductoEnrichmentModes(str, Enum):
    STANDARD = "STANDARD"
    PAGE = "PAGE"
    TABLE = "TABLE"


class TrelloTypes(str, Enum):
    CARD = "CARD"
    BOARD = "BOARD"


class ContentPublishingServiceTypes(str, Enum):
    ELEVEN_LABS_AUDIO = "ELEVEN_LABS_AUDIO"
    OPEN_AI_IMAGE = "OPEN_AI_IMAGE"
    GOOGLE_IMAGE = "GOOGLE_IMAGE"
    OPEN_AI_VIDEO = "OPEN_AI_VIDEO"
    GOOGLE_VIDEO = "GOOGLE_VIDEO"
    TEXT = "TEXT"
    QUIVER_IMAGE = "QUIVER_IMAGE"
    PARALLEL_RESEARCH = "PARALLEL_RESEARCH"


class LinkedInPostContentTypes(str, Enum):
    PHOTOS = "PHOTOS"
    VIDEOS = "VIDEOS"
    DOCUMENTS = "DOCUMENTS"
    JOBS = "JOBS"
    COLLABORATIVE_ARTICLES = "COLLABORATIVE_ARTICLES"
    LIVE_VIDEOS = "LIVE_VIDEOS"


class StorageGateTypes(str, Enum):
    MODEL = "MODEL"
    WEBHOOK = "WEBHOOK"


class ParallelProcessors(str, Enum):
    LITE = "LITE"
    BASE = "BASE"
    CORE = "CORE"
    CORE2X = "CORE2X"
    PRO = "PRO"
    ULTRA = "ULTRA"
    ULTRA2X = "ULTRA2X"
    ULTRA4X = "ULTRA4X"
    ULTRA8X = "ULTRA8X"
    LITE_FAST = "LITE_FAST"
    BASE_FAST = "BASE_FAST"
    CORE_FAST = "CORE_FAST"
    CORE2X_FAST = "CORE2X_FAST"
    PRO_FAST = "PRO_FAST"
    ULTRA_FAST = "ULTRA_FAST"
    ULTRA2X_FAST = "ULTRA2X_FAST"
    ULTRA4X_FAST = "ULTRA4X_FAST"
    ULTRA8X_FAST = "ULTRA8X_FAST"


class ObservableTypes(str, Enum):
    CATEGORY = "CATEGORY"
    LABEL = "LABEL"
    EMOTION = "EMOTION"
    EVENT = "EVENT"
    INVESTMENT = "INVESTMENT"
    INVESTMENT_FUND = "INVESTMENT_FUND"
    ORGANIZATION = "ORGANIZATION"
    PERSON = "PERSON"
    PLACE = "PLACE"
    PRODUCT = "PRODUCT"
    REPO = "REPO"
    SOFTWARE = "SOFTWARE"
    MEDICAL_STUDY = "MEDICAL_STUDY"
    MEDICAL_CONDITION = "MEDICAL_CONDITION"
    MEDICAL_GUIDELINE = "MEDICAL_GUIDELINE"
    MEDICAL_DRUG = "MEDICAL_DRUG"
    MEDICAL_DRUG_CLASS = "MEDICAL_DRUG_CLASS"
    MEDICAL_INDICATION = "MEDICAL_INDICATION"
    MEDICAL_CONTRAINDICATION = "MEDICAL_CONTRAINDICATION"
    MEDICAL_TEST = "MEDICAL_TEST"
    MEDICAL_DEVICE = "MEDICAL_DEVICE"
    MEDICAL_THERAPY = "MEDICAL_THERAPY"
    MEDICAL_PROCEDURE = "MEDICAL_PROCEDURE"


class CalendarReminderMethod(str, Enum):
    EMAIL = "EMAIL"
    POPUP = "POPUP"
    SMS = "SMS"


class MedicalDrugClassFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class GitHubCommitAuthenticationTypes(str, Enum):
    PERSONAL_ACCESS_TOKEN = "PERSONAL_ACCESS_TOKEN"
    O_AUTH = "O_AUTH"
    CONNECTOR = "CONNECTOR"


class CrustdataWatcherSignalTypes(str, Enum):
    COMPANY_JOB_POSTINGS = "COMPANY_JOB_POSTINGS"
    COMPANY_LINKED_IN_POSTS = "COMPANY_LINKED_IN_POSTS"
    COMPANY_NEWS_MENTIONS = "COMPANY_NEWS_MENTIONS"
    COMPANY_FUNDING_ROUND = "COMPANY_FUNDING_ROUND"
    COMPANY_HEADCOUNT_GROWTH = "COMPANY_HEADCOUNT_GROWTH"
    PERSON_PROFILE_UPDATES = "PERSON_PROFILE_UPDATES"
    PERSON_LINKED_IN_POSTS = "PERSON_LINKED_IN_POSTS"
    JOB_POSTING_BY_KEYWORD = "JOB_POSTING_BY_KEYWORD"
    NEW_FUNDING_ANNOUNCEMENTS = "NEW_FUNDING_ANNOUNCEMENTS"
    LINKED_IN_POST_WITH_KEYWORD = "LINKED_IN_POST_WITH_KEYWORD"
    HEADCOUNT_GROWTH_DISCOVERY = "HEADCOUNT_GROWTH_DISCOVERY"
    PERSON_STARTING_NEW_POSITION = "PERSON_STARTING_NEW_POSITION"
    JOB_POSTING_BY_LOCATION = "JOB_POSTING_BY_LOCATION"
    COMPANY_DEPARTMENT_HEADCOUNT = "COMPANY_DEPARTMENT_HEADCOUNT"
    FIRST_PERSON_HIRED_IN_DEPARTMENT = "FIRST_PERSON_HIRED_IN_DEPARTMENT"
    FIRST_PERSON_HIRED_INTERNATIONALLY = "FIRST_PERSON_HIRED_INTERNATIONALLY"
    EMPLOYEE_LOCATION_TWO_COUNTRIES = "EMPLOYEE_LOCATION_TWO_COUNTRIES"
    HEADCOUNT_GROWTH_OVER_BASELINE = "HEADCOUNT_GROWTH_OVER_BASELINE"
    PERSON_DISCOVERY_VIA_FILTERS = "PERSON_DISCOVERY_VIA_FILTERS"


class EmotionFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class QuiverImageModels(str, Enum):
    ARROW_PREVIEW = "ARROW_PREVIEW"
    CUSTOM = "CUSTOM"


class EntityTypes(str, Enum):
    ACTIVITY = "ACTIVITY"
    AGENT = "AGENT"
    ALERT = "ALERT"
    CATEGORY = "CATEGORY"
    COLLECTION = "COLLECTION"
    CONNECTOR = "CONNECTOR"
    CONTENT = "CONTENT"
    CONVERSATION = "CONVERSATION"
    EVENT = "EVENT"
    FACT = "FACT"
    FEED = "FEED"
    INVESTMENT = "INVESTMENT"
    INVESTMENT_FUND = "INVESTMENT_FUND"
    JOB = "JOB"
    LABEL = "LABEL"
    EMOTION = "EMOTION"
    METADATA = "METADATA"
    MEDICAL_STUDY = "MEDICAL_STUDY"
    MEDICAL_CONDITION = "MEDICAL_CONDITION"
    MEDICAL_GUIDELINE = "MEDICAL_GUIDELINE"
    MEDICAL_DRUG = "MEDICAL_DRUG"
    MEDICAL_DRUG_CLASS = "MEDICAL_DRUG_CLASS"
    MEDICAL_INDICATION = "MEDICAL_INDICATION"
    MEDICAL_CONTRAINDICATION = "MEDICAL_CONTRAINDICATION"
    MEDICAL_TEST = "MEDICAL_TEST"
    MEDICAL_DEVICE = "MEDICAL_DEVICE"
    MEDICAL_THERAPY = "MEDICAL_THERAPY"
    MEDICAL_PROCEDURE = "MEDICAL_PROCEDURE"
    OBSERVATION = "OBSERVATION"
    ORGANIZATION = "ORGANIZATION"
    PERSON = "PERSON"
    PERSONA = "PERSONA"
    PLACE = "PLACE"
    PRODUCT = "PRODUCT"
    PROJECT = "PROJECT"
    RENDITION = "RENDITION"
    REPO = "REPO"
    SITE = "SITE"
    SKILL = "SKILL"
    SOFTWARE = "SOFTWARE"
    SPECIFICATION = "SPECIFICATION"
    USER = "USER"
    VIEW = "VIEW"
    WORKFLOW = "WORKFLOW"


class ConversationSearchTypes(str, Enum):
    NONE = "NONE"
    VECTOR = "VECTOR"
    HYBRID = "HYBRID"


class EventFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class WaterfallDepths(str, Enum):
    LOW = "LOW"
    MEDIUM = "MEDIUM"
    HIGH = "HIGH"


class ZendeskAuthenticationTypes(str, Enum):
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class EntityResolutionStrategyTypes(str, Enum):
    NONE = "NONE"
    AUTOMATIC = "AUTOMATIC"


class AttioMeetingAuthenticationTypes(str, Enum):
    API_KEY = "API_KEY"
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class OpenAIModels(str, Enum):
    GPT35_TURBO = "GPT35_TURBO"
    GPT35_TURBO_0613 = "GPT35_TURBO_0613"
    GPT35_TURBO_16K = "GPT35_TURBO_16K"
    GPT35_TURBO_16K_0613 = "GPT35_TURBO_16K_0613"
    GPT35_TURBO_16K_1106 = "GPT35_TURBO_16K_1106"
    GPT35_TURBO_16K_0125 = "GPT35_TURBO_16K_0125"
    GPT4 = "GPT4"
    GPT4_0613 = "GPT4_0613"
    GPT4_TURBO_VISION_128K = "GPT4_TURBO_VISION_128K"
    GPT4_TURBO_VISION_128K_1106 = "GPT4_TURBO_VISION_128K_1106"
    GPT4_32K = "GPT4_32K"
    GPT4_32K_0613 = "GPT4_32K_0613"
    GPT4_TURBO_128K = "GPT4_TURBO_128K"
    GPT4_TURBO_128K_1106 = "GPT4_TURBO_128K_1106"
    GPT4_TURBO_128K_0125 = "GPT4_TURBO_128K_0125"
    GPT4_TURBO_128K_20240409 = "GPT4_TURBO_128K_20240409"
    GPT4O_128K_20240513 = "GPT4O_128K_20240513"
    GPT4O_128K_20240806 = "GPT4O_128K_20240806"
    GPT4O_128K_20241120 = "GPT4O_128K_20241120"
    GPT4O_128K = "GPT4O_128K"
    GPT4O_MINI_128K_20240718 = "GPT4O_MINI_128K_20240718"
    GPT4O_MINI_128K = "GPT4O_MINI_128K"
    GPT4O_CHAT_128K = "GPT4O_CHAT_128K"
    GPT41_NANO_1024K = "GPT41_NANO_1024K"
    GPT41_NANO_1024K_20250414 = "GPT41_NANO_1024K_20250414"
    GPT41_MINI_1024K = "GPT41_MINI_1024K"
    GPT41_MINI_1024K_20250414 = "GPT41_MINI_1024K_20250414"
    GPT41_1024K = "GPT41_1024K"
    GPT41_1024K_20250414 = "GPT41_1024K_20250414"
    GPT45_PREVIEW_128K = "GPT45_PREVIEW_128K"
    GPT45_PREVIEW_128K_20250227 = "GPT45_PREVIEW_128K_20250227"
    GPT5_CHAT_400K = "GPT5_CHAT_400K"
    GPT5_NANO_400K = "GPT5_NANO_400K"
    GPT5_NANO_400K_20250807 = "GPT5_NANO_400K_20250807"
    GPT5_MINI_400K = "GPT5_MINI_400K"
    GPT5_MINI_400K_20250807 = "GPT5_MINI_400K_20250807"
    GPT5_400K = "GPT5_400K"
    GPT5_400K_20250807 = "GPT5_400K_20250807"
    GPT51_400K = "GPT51_400K"
    GPT51_400K_20251113 = "GPT51_400K_20251113"
    GPT52_400K = "GPT52_400K"
    GPT52_400K_20251211 = "GPT52_400K_20251211"
    GPT54_NANO_400K = "GPT54_NANO_400K"
    GPT54_NANO_400K_20260317 = "GPT54_NANO_400K_20260317"
    GPT54_MINI_400K = "GPT54_MINI_400K"
    GPT54_MINI_400K_20260317 = "GPT54_MINI_400K_20260317"
    GPT54_1024K = "GPT54_1024K"
    GPT54_1024K_20260305 = "GPT54_1024K_20260305"
    O1_MINI_128K = "O1_MINI_128K"
    O1_MINI_128K_20240912 = "O1_MINI_128K_20240912"
    O1_PREVIEW_128K = "O1_PREVIEW_128K"
    O1_PREVIEW_128K_20240912 = "O1_PREVIEW_128K_20240912"
    O1_200K = "O1_200K"
    O1_200K_20241217 = "O1_200K_20241217"
    O3_MINI_200K = "O3_MINI_200K"
    O3_MINI_200K_20250131 = "O3_MINI_200K_20250131"
    O3_200K = "O3_200K"
    O3_200K_20250416 = "O3_200K_20250416"
    O4_MINI_200K = "O4_MINI_200K"
    O4_MINI_200K_20250416 = "O4_MINI_200K_20250416"
    ADA_002 = "ADA_002"
    EMBEDDING_3_SMALL = "EMBEDDING_3_SMALL"
    EMBEDDING_3_LARGE = "EMBEDDING_3_LARGE"
    CUSTOM = "CUSTOM"


class FeedServiceTypes(str, Enum):
    GOOGLE_BLOB = "GOOGLE_BLOB"
    S3_BLOB = "S3_BLOB"
    AZURE_BLOB = "AZURE_BLOB"
    AZURE_FILE = "AZURE_FILE"
    SHARE_POINT = "SHARE_POINT"
    ONE_DRIVE = "ONE_DRIVE"
    GOOGLE_DRIVE = "GOOGLE_DRIVE"
    DROPBOX = "DROPBOX"
    BOX = "BOX"
    GOOGLE_EMAIL = "GOOGLE_EMAIL"
    MICROSOFT_EMAIL = "MICROSOFT_EMAIL"
    ATLASSIAN_JIRA = "ATLASSIAN_JIRA"
    ATLASSIAN_CONFLUENCE = "ATLASSIAN_CONFLUENCE"
    TRELLO = "TRELLO"
    LINEAR = "LINEAR"
    GIT_HUB_ISSUES = "GIT_HUB_ISSUES"
    GIT_HUB_PULL_REQUESTS = "GIT_HUB_PULL_REQUESTS"
    GIT_HUB_COMMITS = "GIT_HUB_COMMITS"
    GIT_HUB = "GIT_HUB"
    INTERCOM_ARTICLES = "INTERCOM_ARTICLES"
    ZENDESK_ARTICLES = "ZENDESK_ARTICLES"
    INTERCOM_TICKETS = "INTERCOM_TICKETS"
    ZENDESK_TICKETS = "ZENDESK_TICKETS"
    GOOGLE_CALENDAR = "GOOGLE_CALENDAR"
    MICROSOFT_CALENDAR = "MICROSOFT_CALENDAR"
    GOOGLE_CONTACTS = "GOOGLE_CONTACTS"
    MICROSOFT_CONTACTS = "MICROSOFT_CONTACTS"
    ATTIO_OBJECTS = "ATTIO_OBJECTS"
    ATTIO_TASKS = "ATTIO_TASKS"
    ATTIO_NOTES = "ATTIO_NOTES"
    SALESFORCE_OBJECTS = "SALESFORCE_OBJECTS"
    SALESFORCE_TASKS = "SALESFORCE_TASKS"
    SALESFORCE_NOTES = "SALESFORCE_NOTES"
    HUB_SPOT_OBJECTS = "HUB_SPOT_OBJECTS"
    HUB_SPOT_TASKS = "HUB_SPOT_TASKS"
    HUB_SPOT_TICKETS = "HUB_SPOT_TICKETS"
    ASANA = "ASANA"
    MONDAY = "MONDAY"
    HUB_SPOT_NOTES = "HUB_SPOT_NOTES"
    HUB_SPOT_MEETING = "HUB_SPOT_MEETING"
    HUB_SPOT_CONVERSATIONS = "HUB_SPOT_CONVERSATIONS"
    FIREFLIES = "FIREFLIES"
    ATTIO_MEETING = "ATTIO_MEETING"
    FATHOM = "FATHOM"
    KRISP = "KRISP"
    SALESFORCE_ECI = "SALESFORCE_ECI"
    PARALLEL = "PARALLEL"
    CRUSTDATA = "CRUSTDATA"
    BAMBOO_HR = "BAMBOO_HR"
    GUSTO_HRIS = "GUSTO_HRIS"
    INTERCOM_CONVERSATIONS = "INTERCOM_CONVERSATIONS"
    JIRA_EPICS = "JIRA_EPICS"
    GIT_HUB_MILESTONES = "GIT_HUB_MILESTONES"
    LINEAR_INITIATIVES = "LINEAR_INITIATIVES"
    PRODUCTLANE_THREADS = "PRODUCTLANE_THREADS"
    PRODUCTLANE_ISSUES = "PRODUCTLANE_ISSUES"
    PRODUCTLANE_OBJECTS = "PRODUCTLANE_OBJECTS"
    PRODUCTLANE_CHANGELOGS = "PRODUCTLANE_CHANGELOGS"
    PRODUCTLANE_ARTICLES = "PRODUCTLANE_ARTICLES"
    NYNE = "NYNE"


class TextTypes(str, Enum):
    PLAIN = "PLAIN"
    MARKDOWN = "MARKDOWN"
    HTML = "HTML"


class SearchServiceTypes(str, Enum):
    PARALLEL = "PARALLEL"
    TAVILY = "TAVILY"
    EXA = "EXA"
    EXA_CODE = "EXA_CODE"
    PERPLEXITY = "PERPLEXITY"
    PODSCAN = "PODSCAN"
    CRUSTDATA = "CRUSTDATA"


class FeedSyncMode(str, Enum):
    ARCHIVE = "ARCHIVE"
    MIRROR = "MIRROR"


class FilePreparationServiceTypes(str, Enum):
    AZURE_DOCUMENT_INTELLIGENCE = "AZURE_DOCUMENT_INTELLIGENCE"
    DEEPGRAM = "DEEPGRAM"
    DOCUMENT = "DOCUMENT"
    EMAIL = "EMAIL"
    PAGE = "PAGE"
    REDUCTO_DOCUMENT = "REDUCTO_DOCUMENT"
    MODEL_DOCUMENT = "MODEL_DOCUMENT"
    ASSEMBLY_AI = "ASSEMBLY_AI"
    MISTRAL_DOCUMENT = "MISTRAL_DOCUMENT"
    ELEVEN_LABS_SCRIBE = "ELEVEN_LABS_SCRIBE"


class GitHubRepositorySortTypes(str, Enum):
    ALPHABETICAL = "ALPHABETICAL"
    RANKED = "RANKED"


class UserTypes(str, Enum):
    HUMAN = "HUMAN"
    AGENT = "AGENT"


class GoogleImageResolutionTypes(str, Enum):
    RESOLUTION_512 = "RESOLUTION_512"
    RESOLUTION_1_K = "RESOLUTION_1_K"
    RESOLUTION_2_K = "RESOLUTION_2_K"
    RESOLUTION_4_K = "RESOLUTION_4_K"


class CalendarAttendeeResponseStatus(str, Enum):
    NEEDS_ACTION = "NEEDS_ACTION"
    DECLINED = "DECLINED"
    TENTATIVE = "TENTATIVE"
    ACCEPTED = "ACCEPTED"


class SearchQueryTypes(str, Enum):
    SIMPLE = "SIMPLE"
    FULL = "FULL"


class OrganizationFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class OpenAIReasoningEffortLevels(str, Enum):
    MINIMAL = "MINIMAL"
    LOW = "LOW"
    MEDIUM = "MEDIUM"
    HIGH = "HIGH"


class MistralModels(str, Enum):
    MIXTRAL_8X7B_INSTRUCT = "MIXTRAL_8X7B_INSTRUCT"
    MISTRAL_NEMO = "MISTRAL_NEMO"
    MISTRAL_SMALL = "MISTRAL_SMALL"
    MISTRAL_MEDIUM = "MISTRAL_MEDIUM"
    MISTRAL_LARGE = "MISTRAL_LARGE"
    PIXTRAL_12B_2409 = "PIXTRAL_12B_2409"
    PIXTRAL_LARGE = "PIXTRAL_LARGE"
    MISTRAL_EMBED = "MISTRAL_EMBED"
    CUSTOM = "CUSTOM"


class StorageGateRejectionActions(str, Enum):
    DELETE = "DELETE"
    REJECT = "REJECT"


class ImageProjectionTypes(str, Enum):
    EQUIRECTANGULAR = "EQUIRECTANGULAR"
    CYLINDRICAL = "CYLINDRICAL"


class HubSpotFeedAuthenticationTypes(str, Enum):
    USER = "USER"
    PRIVATE_APP = "PRIVATE_APP"
    CONNECTOR = "CONNECTOR"


class IntegrationServiceTypes(str, Enum):
    SLACK = "SLACK"
    WEB_HOOK = "WEB_HOOK"
    EMAIL = "EMAIL"
    TWITTER = "TWITTER"
    MCP = "MCP"


class CerebrasModels(str, Enum):
    LLAMA_4_SCOUT_17B = "LLAMA_4_SCOUT_17B"
    LLAMA_3_3_70B = "LLAMA_3_3_70B"
    LLAMA_3_1_8B = "LLAMA_3_1_8B"
    QWEN_3_32B = "QWEN_3_32B"
    CUSTOM = "CUSTOM"


class IntercomIssueAuthenticationTypes(str, Enum):
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class CohereModels(str, Enum):
    EMBED_ENGLISH_3_0 = "EMBED_ENGLISH_3_0"
    EMBED_MULTILINGUAL_3_0 = "EMBED_MULTILINGUAL_3_0"
    COMMAND_R = "COMMAND_R"
    COMMAND_R_202403 = "COMMAND_R_202403"
    COMMAND_R_202408 = "COMMAND_R_202408"
    COMMAND_R_PLUS = "COMMAND_R_PLUS"
    COMMAND_R_PLUS_202404 = "COMMAND_R_PLUS_202404"
    COMMAND_R_PLUS_202408 = "COMMAND_R_PLUS_202408"
    COMMAND_R7_B_202412 = "COMMAND_R7_B_202412"
    COMMAND_A = "COMMAND_A"
    COMMAND_A_202503 = "COMMAND_A_202503"
    CUSTOM = "CUSTOM"


class SharePointAuthenticationTypes(str, Enum):
    APPLICATION = "APPLICATION"
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class ConversationStrategyTypes(str, Enum):
    WINDOWED = "WINDOWED"
    SUMMARIZED = "SUMMARIZED"


class AsanaAuthenticationTypes(str, Enum):
    PERSONAL_ACCESS_TOKEN = "PERSONAL_ACCESS_TOKEN"
    O_AUTH = "O_AUTH"


class MicrosoftEmailAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class EnvironmentTypes(str, Enum):
    DEVELOPMENT = "DEVELOPMENT"
    PRODUCTION = "PRODUCTION"


class ExaSearchTypes(str, Enum):
    AUTO = "AUTO"
    INSTANT = "INSTANT"
    FAST = "FAST"
    DEEP = "DEEP"
    NEURAL = "NEURAL"


class GoogleContactsAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class CalendarRecurrencePattern(str, Enum):
    DAILY = "DAILY"
    WEEKLY = "WEEKLY"
    MONTHLY = "MONTHLY"
    YEARLY = "YEARLY"


class RelationshipDirections(str, Enum):
    INCOMING = "INCOMING"
    OUTGOING = "OUTGOING"


class ModelServiceTypes(str, Enum):
    GOOGLE = "GOOGLE"
    ANTHROPIC = "ANTHROPIC"
    AZURE_AI = "AZURE_AI"
    AZURE_OPEN_AI = "AZURE_OPEN_AI"
    OPEN_AI = "OPEN_AI"
    REPLICATE = "REPLICATE"
    GROQ = "GROQ"
    CEREBRAS = "CEREBRAS"
    MISTRAL = "MISTRAL"
    COHERE = "COHERE"
    DEEPSEEK = "DEEPSEEK"
    JINA = "JINA"
    VOYAGE = "VOYAGE"
    BEDROCK = "BEDROCK"
    XAI = "XAI"
    TWELVE_LABS = "TWELVE_LABS"
    QUIVER = "QUIVER"


class AgentChannelTypes(str, Enum):
    VOICE = "VOICE"
    EMAIL = "EMAIL"
    SLACK = "SLACK"
    TEAMS = "TEAMS"
    DISCORD = "DISCORD"


class AgentTypes(str, Enum):
    AGENT = "AGENT"


class MicrosoftCalendarAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class ReplicateModels(str, Enum):
    MISTRAL_7B = "MISTRAL_7B"
    MISTRAL_7B_INSTRUCT = "MISTRAL_7B_INSTRUCT"
    LLAMA_2_7B = "LLAMA_2_7B"
    LLAMA_2_13B = "LLAMA_2_13B"
    LLAMA_2_70B = "LLAMA_2_70B"
    LLAMA_2_7B_CHAT = "LLAMA_2_7B_CHAT"
    LLAMA_2_13B_CHAT = "LLAMA_2_13B_CHAT"
    LLAMA_2_70B_CHAT = "LLAMA_2_70B_CHAT"
    CUSTOM = "CUSTOM"


class SiteTypes(str, Enum):
    WATCH = "WATCH"
    SWEEP = "SWEEP"
    STORAGE = "STORAGE"


class ExtractionTypes(str, Enum):
    ENTITIES = "ENTITIES"
    FACTS = "FACTS"


class TimeIntervalTypes(str, Enum):
    MINUTE = "MINUTE"
    HOUR = "HOUR"
    DAY = "DAY"
    WEEK = "WEEK"
    MONTH = "MONTH"
    QUARTER = "QUARTER"
    YEAR = "YEAR"


class OrientationTypes(str, Enum):
    TOP_LEFT = "TOP_LEFT"
    TOP_RIGHT = "TOP_RIGHT"
    BOTTOM_RIGHT = "BOTTOM_RIGHT"
    BOTTOM_LEFT = "BOTTOM_LEFT"
    LEFT_TOP = "LEFT_TOP"
    RIGHT_TOP = "RIGHT_TOP"
    RIGHT_BOTTOM = "RIGHT_BOTTOM"
    LEFT_BOTTOM = "LEFT_BOTTOM"


class ProductFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class FilterMode(str, Enum):
    ANY = "ANY"
    ONLY = "ONLY"
    ALL = "ALL"


class OAuthProviders(str, Enum):
    DROPBOX = "DROPBOX"
    BOX = "BOX"
    GOOGLE = "GOOGLE"
    MICROSOFT = "MICROSOFT"
    GIT_HUB = "GIT_HUB"
    SLACK = "SLACK"
    HUB_SPOT = "HUB_SPOT"
    NOTION = "NOTION"
    ATLASSIAN = "ATLASSIAN"
    INTERCOM = "INTERCOM"
    ZENDESK = "ZENDESK"
    ATTIO = "ATTIO"
    SALESFORCE = "SALESFORCE"
    LINEAR = "LINEAR"
    TWITTER = "TWITTER"


class ConfluenceAuthenticationTypes(str, Enum):
    TOKEN = "TOKEN"
    CONNECTOR = "CONNECTOR"


class UnitTypes(str, Enum):
    KILOMETER = "KILOMETER"
    METER = "METER"
    CENTIMETER = "CENTIMETER"
    MILLIMETER = "MILLIMETER"
    MICROMETER = "MICROMETER"
    NANOMETER = "NANOMETER"
    ANGSTROM = "ANGSTROM"
    DECIMETER = "DECIMETER"
    DECAMETER = "DECAMETER"
    HECTOMETER = "HECTOMETER"
    GIGAMETER = "GIGAMETER"
    ASTRONOMICAL_UNIT = "ASTRONOMICAL_UNIT"
    LIGHT_YEAR = "LIGHT_YEAR"
    PARSEC = "PARSEC"
    MILE = "MILE"
    YARD = "YARD"
    FOOT = "FOOT"
    INCH = "INCH"
    MIL = "MIL"
    MICRO_INCH = "MICRO_INCH"
    CUSTOM = "CUSTOM"
    UNITLESS = "UNITLESS"


class ParallelGenerators(str, Enum):
    BASE = "BASE"
    CORE = "CORE"
    PRO = "PRO"


class AttioIssueAuthenticationTypes(str, Enum):
    API_KEY = "API_KEY"
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class ContentIndexingServiceTypes(str, Enum):
    AZURE_AI_LANGUAGE = "AZURE_AI_LANGUAGE"


class MicrosoftContactsAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class CategoryFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class PersonFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class VideoAspectRatioTypes(str, Enum):
    LANDSCAPE_16X9 = "LANDSCAPE_16X9"
    PORTRAIT_9X16 = "PORTRAIT_9X16"


class StoragePolicyTypes(str, Enum):
    ARCHIVE = "ARCHIVE"
    MINIMIZE = "MINIMIZE"


class LinkedInPostListingTypes(str, Enum):
    COMPANY = "COMPANY"
    PERSON = "PERSON"
    KEYWORD_SEARCH = "KEYWORD_SEARCH"


class TwelveLabsEmbeddingOptions(str, Enum):
    VISUAL = "VISUAL"
    AUDIO = "AUDIO"
    TRANSCRIPTION = "TRANSCRIPTION"


class CalendarListingTypes(str, Enum):
    PAST = "PAST"
    NEW = "NEW"


class EntityEnrichmentServiceTypes(str, Enum):
    PARALLEL = "PARALLEL"
    DIFFBOT = "DIFFBOT"
    WIKIPEDIA = "WIKIPEDIA"
    CRUNCHBASE = "CRUNCHBASE"
    FHIR = "FHIR"
    RADAR = "RADAR"
    CRUSTDATA = "CRUSTDATA"
    NYNE = "NYNE"
    WATERFALL = "WATERFALL"


class DeviceTypes(str, Enum):
    DRONE = "DRONE"
    ROBOT = "ROBOT"
    MOBILE = "MOBILE"
    CAMERA = "CAMERA"
    STREAM = "STREAM"
    SCREEN = "SCREEN"
    GEOSPATIAL = "GEOSPATIAL"
    UNKNOWN = "UNKNOWN"


class VideoSizeTypes(str, Enum):
    HD_PORTRAIT = "HD_PORTRAIT"
    HD_LANDSCAPE = "HD_LANDSCAPE"
    FULL_HD_PORTRAIT = "FULL_HD_PORTRAIT"
    FULL_HD_LANDSCAPE = "FULL_HD_LANDSCAPE"


class ContentClassificationServiceTypes(str, Enum):
    REGEX = "REGEX"
    MODEL = "MODEL"


class BoxAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class ContentSourceTypes(str, Enum):
    FRAME = "FRAME"
    DOCUMENT = "DOCUMENT"
    TRANSCRIPT = "TRANSCRIPT"


class GoogleModels(str, Enum):
    GEMINI_2_5_PRO = "GEMINI_2_5_PRO"
    GEMINI_2_5_PRO_PREVIEW = "GEMINI_2_5_PRO_PREVIEW"
    GEMINI_2_5_PRO_EXPERIMENTAL = "GEMINI_2_5_PRO_EXPERIMENTAL"
    GEMINI_3_PRO_PREVIEW = "GEMINI_3_PRO_PREVIEW"
    GEMINI_3_1_PRO_PREVIEW = "GEMINI_3_1_PRO_PREVIEW"
    GEMINI_3_FLASH_PREVIEW = "GEMINI_3_FLASH_PREVIEW"
    GEMINI_2_5_FLASH = "GEMINI_2_5_FLASH"
    GEMINI_FLASH_LATEST = "GEMINI_FLASH_LATEST"
    GEMINI_2_5_FLASH_PREVIEW = "GEMINI_2_5_FLASH_PREVIEW"
    GEMINI_2_5_FLASH_LITE = "GEMINI_2_5_FLASH_LITE"
    GEMINI_FLASH_LITE_LATEST = "GEMINI_FLASH_LITE_LATEST"
    GEMINI_2_0_PRO_EXPERIMENTAL = "GEMINI_2_0_PRO_EXPERIMENTAL"
    GEMINI_2_0_FLASH_THINKING_EXPERIMENTAL = "GEMINI_2_0_FLASH_THINKING_EXPERIMENTAL"
    GEMINI_2_0_FLASH_EXPERIMENTAL = "GEMINI_2_0_FLASH_EXPERIMENTAL"
    GEMINI_2_0_FLASH = "GEMINI_2_0_FLASH"
    GEMINI_2_0_FLASH_001 = "GEMINI_2_0_FLASH_001"
    GEMINI_1_5_FLASH_8B = "GEMINI_1_5_FLASH_8B"
    GEMINI_1_5_FLASH_8B_001 = "GEMINI_1_5_FLASH_8B_001"
    GEMINI_1_5_FLASH = "GEMINI_1_5_FLASH"
    GEMINI_1_5_FLASH_001 = "GEMINI_1_5_FLASH_001"
    GEMINI_1_5_PRO = "GEMINI_1_5_PRO"
    GEMINI_1_5_PRO_001 = "GEMINI_1_5_PRO_001"
    GEMINI_1_5_FLASH_002 = "GEMINI_1_5_FLASH_002"
    GEMINI_1_5_PRO_002 = "GEMINI_1_5_PRO_002"
    EMBEDDING_004 = "EMBEDDING_004"
    GEMINI_EMBEDDING_001 = "GEMINI_EMBEDDING_001"
    GEMINI_EMBEDDING_2_PREVIEW = "GEMINI_EMBEDDING_2_PREVIEW"
    CUSTOM = "CUSTOM"


class ApplyPolicy(str, Enum):
    BEFORE_RESOLVER = "BEFORE_RESOLVER"
    AFTER_RESOLVER = "AFTER_RESOLVER"
    VALIDATION = "VALIDATION"


class FeedConnectorTypes(str, Enum):
    GOOGLE = "GOOGLE"
    AMAZON = "AMAZON"
    AZURE = "AZURE"
    SHARE_POINT = "SHARE_POINT"
    ONE_DRIVE = "ONE_DRIVE"
    GOOGLE_DRIVE = "GOOGLE_DRIVE"
    DROPBOX = "DROPBOX"
    BOX = "BOX"
    GOOGLE_EMAIL = "GOOGLE_EMAIL"
    MICROSOFT_EMAIL = "MICROSOFT_EMAIL"
    ATLASSIAN = "ATLASSIAN"
    LINEAR = "LINEAR"
    GIT_HUB = "GIT_HUB"
    INTERCOM = "INTERCOM"
    ZENDESK = "ZENDESK"
    GOOGLE_CALENDAR = "GOOGLE_CALENDAR"
    MICROSOFT_CALENDAR = "MICROSOFT_CALENDAR"
    GOOGLE_CONTACTS = "GOOGLE_CONTACTS"
    MICROSOFT_CONTACTS = "MICROSOFT_CONTACTS"
    ATTIO = "ATTIO"
    SALESFORCE = "SALESFORCE"
    HUB_SPOT = "HUB_SPOT"
    ASANA = "ASANA"
    MONDAY = "MONDAY"
    FIREFLIES = "FIREFLIES"
    ATTIO_MEETING = "ATTIO_MEETING"
    FATHOM = "FATHOM"
    KRISP = "KRISP"
    SALESFORCE_ECI = "SALESFORCE_ECI"
    PARALLEL = "PARALLEL"
    BAMBOO_HR = "BAMBOO_HR"
    GUSTO = "GUSTO"
    PRODUCTLANE = "PRODUCTLANE"


class BillableMetrics(str, Enum):
    BYTES = "BYTES"
    TOKENS = "TOKENS"
    LENGTH = "LENGTH"
    TIME = "TIME"
    UNITS = "UNITS"
    COST = "COST"
    REQUESTS = "REQUESTS"
    CREDITS = "CREDITS"


class TwelveLabsEmbeddingScopes(str, Enum):
    CLIP = "CLIP"
    ASSET = "ASSET"


class JiraAuthenticationTypes(str, Enum):
    TOKEN = "TOKEN"
    CONNECTOR = "CONNECTOR"


class IntercomConversationsAuthenticationTypes(str, Enum):
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class GoogleImageModels(str, Enum):
    GEMINI_2_5_FLASH_IMAGE_PREVIEW = "GEMINI_2_5_FLASH_IMAGE_PREVIEW"
    GEMINI_3_PRO_IMAGE_PREVIEW = "GEMINI_3_PRO_IMAGE_PREVIEW"
    GEMINI_3_1_FLASH_IMAGE_PREVIEW = "GEMINI_3_1_FLASH_IMAGE_PREVIEW"
    CUSTOM = "CUSTOM"


class XAIModels(str, Enum):
    GROK_4 = "GROK_4"
    GROK_3 = "GROK_3"
    GROK_3_MINI = "GROK_3_MINI"
    CUSTOM = "CUSTOM"



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class RejectContent(BaseModel):
    reject_content: Optional["RejectContentRejectContent"] = Field(
        alias="rejectContent"
    )


class RejectContentRejectContent(BaseModel):
    id: str
    state: EntityState


RejectContent.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllPersonas(BaseModel):
    delete_all_personas: Optional[
        list[Optional["DeleteAllPersonasDeleteAllPersonas"]]
    ] = Field(alias="deleteAllPersonas")


class DeleteAllPersonasDeleteAllPersonas(BaseModel):
    id: str
    state: EntityState


DeleteAllPersonas.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteInvestment(BaseModel):
    delete_investment: Optional["DeleteInvestmentDeleteInvestment"] = Field(
        alias="deleteInvestment"
    )


class DeleteInvestmentDeleteInvestment(BaseModel):
    id: str
    state: EntityState


DeleteInvestment.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class FeedExists(BaseModel):
    feed_exists: Optional["FeedExistsFeedExists"] = Field(alias="feedExists")


class FeedExistsFeedExists(BaseModel):
    result: Optional[bool]


FeedExists.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class EnrichPersons(BaseModel):
    enrich_persons: Optional[list[Optional["EnrichPersonsEnrichPersons"]]] = Field(
        alias="enrichPersons"
    )


class EnrichPersonsEnrichPersons(BaseModel):
    id: str
    name: str


EnrichPersons.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteViews(BaseModel):
    delete_views: Optional[list[Optional["DeleteViewsDeleteViews"]]] = Field(
        alias="deleteViews"
    )


class DeleteViewsDeleteViews(BaseModel):
    id: str
    state: EntityState


DeleteViews.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalTest(BaseModel):
    delete_medical_test: Optional["DeleteMedicalTestDeleteMedicalTest"] = Field(
        alias="deleteMedicalTest"
    )


class DeleteMedicalTestDeleteMedicalTest(BaseModel):
    id: str
    state: EntityState


DeleteMedicalTest.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from .base_model import BaseModel
from .enums import ObservableTypes


class QueryObservables(BaseModel):
    observables: Optional["QueryObservablesObservables"]


class QueryObservablesObservables(BaseModel):
    results: Optional[list[Optional["QueryObservablesObservablesResults"]]]


class QueryObservablesObservablesResults(BaseModel):
    type: ObservableTypes
    observable: "QueryObservablesObservablesResultsObservable"


class QueryObservablesObservablesResultsObservable(BaseModel):
    id: str
    name: Optional[str]


QueryObservables.model_rebuild()
QueryObservablesObservables.model_rebuild()
QueryObservablesObservablesResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryJiraProjects(BaseModel):
    jira_projects: Optional["QueryJiraProjectsJiraProjects"] = Field(
        alias="jiraProjects"
    )


class QueryJiraProjectsJiraProjects(BaseModel):
    results: Optional[list[Optional["QueryJiraProjectsJiraProjectsResults"]]]


class QueryJiraProjectsJiraProjectsResults(BaseModel):
    identifier: Optional[str]
    name: Optional[str]
    key: Optional[str]


QueryJiraProjects.model_rebuild()
QueryJiraProjectsJiraProjects.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllViews(BaseModel):
    delete_all_views: Optional[list[Optional["DeleteAllViewsDeleteAllViews"]]] = Field(
        alias="deleteAllViews"
    )


class DeleteAllViewsDeleteAllViews(BaseModel):
    id: str
    state: EntityState


DeleteAllViews.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryLabels(BaseModel):
    labels: Optional["QueryLabelsLabels"]


class QueryLabelsLabels(BaseModel):
    results: Optional[list[Optional["QueryLabelsLabelsResults"]]]


class QueryLabelsLabelsResults(BaseModel):
    id: str
    name: str
    description: Optional[str]
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    feeds: Optional[list[Optional["QueryLabelsLabelsResultsFeeds"]]]


class QueryLabelsLabelsResultsFeeds(BaseModel):
    id: str
    name: str


QueryLabels.model_rebuild()
QueryLabelsLabels.model_rebuild()
QueryLabelsLabelsResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryEmotions(BaseModel):
    emotions: Optional["QueryEmotionsEmotions"]


class QueryEmotionsEmotions(BaseModel):
    results: Optional[list[Optional["QueryEmotionsEmotionsResults"]]]


class QueryEmotionsEmotionsResults(BaseModel):
    id: str
    name: str
    description: Optional[str]
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    feeds: Optional[list[Optional["QueryEmotionsEmotionsResultsFeeds"]]]


class QueryEmotionsEmotionsResultsFeeds(BaseModel):
    id: str
    name: str


QueryEmotions.model_rebuild()
QueryEmotionsEmotions.model_rebuild()
QueryEmotionsEmotionsResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteLabels(BaseModel):
    delete_labels: Optional[list[Optional["DeleteLabelsDeleteLabels"]]] = Field(
        alias="deleteLabels"
    )


class DeleteLabelsDeleteLabels(BaseModel):
    id: str
    state: EntityState


DeleteLabels.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteWorkflows(BaseModel):
    delete_workflows: Optional[list[Optional["DeleteWorkflowsDeleteWorkflows"]]] = (
        Field(alias="deleteWorkflows")
    )


class DeleteWorkflowsDeleteWorkflows(BaseModel):
    id: str
    state: EntityState


DeleteWorkflows.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteConnector(BaseModel):
    delete_connector: Optional["DeleteConnectorDeleteConnector"] = Field(
        alias="deleteConnector"
    )


class DeleteConnectorDeleteConnector(BaseModel):
    id: str
    state: EntityState


DeleteConnector.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QuerySlackChannels(BaseModel):
    slack_channels: Optional["QuerySlackChannelsSlackChannels"] = Field(
        alias="slackChannels"
    )


class QuerySlackChannelsSlackChannels(BaseModel):
    results: Optional[list[str]]


QuerySlackChannels.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteEvents(BaseModel):
    delete_events: Optional[list[Optional["DeleteEventsDeleteEvents"]]] = Field(
        alias="deleteEvents"
    )


class DeleteEventsDeleteEvents(BaseModel):
    id: str
    state: EntityState


DeleteEvents.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeletePersonas(BaseModel):
    delete_personas: Optional[list[Optional["DeletePersonasDeletePersonas"]]] = Field(
        alias="deletePersonas"
    )


class DeletePersonasDeletePersonas(BaseModel):
    id: str
    state: EntityState


DeletePersonas.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityTypes


class QueryFactsGraph(BaseModel):
    facts: Optional["QueryFactsGraphFacts"]


class QueryFactsGraphFacts(BaseModel):
    graph: Optional["QueryFactsGraphFactsGraph"]


class QueryFactsGraphFactsGraph(BaseModel):
    nodes: Optional[list[Optional["QueryFactsGraphFactsGraphNodes"]]]
    edges: Optional[list[Optional["QueryFactsGraphFactsGraphEdges"]]]


class QueryFactsGraphFactsGraphNodes(BaseModel):
    id: str
    name: str
    type: EntityTypes
    metadata: Optional[str]


class QueryFactsGraphFactsGraphEdges(BaseModel):
    from_: str = Field(alias="from")
    to: str
    relation: Optional[str]


QueryFactsGraph.model_rebuild()
QueryFactsGraphFacts.model_rebuild()
QueryFactsGraphFactsGraph.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class EnrichOrganizations(BaseModel):
    enrich_organizations: Optional[
        list[Optional["EnrichOrganizationsEnrichOrganizations"]]
    ] = Field(alias="enrichOrganizations")


class EnrichOrganizationsEnrichOrganizations(BaseModel):
    id: str
    name: str


EnrichOrganizations.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, FactCategory, ObservableTypes, SourceTypes


class QueryFactsClusters(BaseModel):
    facts: Optional["QueryFactsClustersFacts"]


class QueryFactsClustersFacts(BaseModel):
    results: Optional[list[Optional["QueryFactsClustersFactsResults"]]]
    clusters: Optional[list[Optional["QueryFactsClustersFactsClusters"]]]


class QueryFactsClustersFactsResults(BaseModel):
    id: str
    creation_date: Any = Field(alias="creationDate")
    owner: "QueryFactsClustersFactsResultsOwner"
    state: EntityState
    text: str
    valid_at: Optional[Any] = Field(alias="validAt")
    invalid_at: Optional[Any] = Field(alias="invalidAt")
    relevance: Optional[float]
    mentions: Optional[list[Optional["QueryFactsClustersFactsResultsMentions"]]]
    assertions: Optional[list[Optional["QueryFactsClustersFactsResultsAssertions"]]]
    feeds: Optional[list[Optional["QueryFactsClustersFactsResultsFeeds"]]]
    content: Optional["QueryFactsClustersFactsResultsContent"]
    conversation: Optional["QueryFactsClustersFactsResultsConversation"]
    persona: Optional["QueryFactsClustersFactsResultsPersona"]
    source_type: Optional[SourceTypes] = Field(alias="sourceType")
    category: Optional[FactCategory]
    confidence: Optional[float]


class QueryFactsClustersFactsResultsOwner(BaseModel):
    id: str


class QueryFactsClustersFactsResultsMentions(BaseModel):
    type: Optional[ObservableTypes]
    observable: Optional["QueryFactsClustersFactsResultsMentionsObservable"]
    start: Optional[int]
    end: Optional[int]


class QueryFactsClustersFactsResultsMentionsObservable(BaseModel):
    id: str
    name: Optional[str]


class QueryFactsClustersFactsResultsAssertions(BaseModel):
    text: str
    mentions: Optional[
        list[Optional["QueryFactsClustersFactsResultsAssertionsMentions"]]
    ]


class QueryFactsClustersFactsResultsAssertionsMentions(BaseModel):
    type: Optional[ObservableTypes]
    observable: Optional["QueryFactsClustersFactsResultsAssertionsMentionsObservable"]
    start: Optional[int]
    end: Optional[int]


class QueryFactsClustersFactsResultsAssertionsMentionsObservable(BaseModel):
    id: str
    name: Optional[str]


class QueryFactsClustersFactsResultsFeeds(BaseModel):
    id: str
    name: str


class QueryFactsClustersFactsResultsContent(BaseModel):
    id: str
    name: str


class QueryFactsClustersFactsResultsConversation(BaseModel):
    id: str
    name: str


class QueryFactsClustersFactsResultsPersona(BaseModel):
    id: str
    name: str


class QueryFactsClustersFactsClusters(BaseModel):
    entities: list["QueryFactsClustersFactsClustersEntities"]
    similarity: Optional[float]


class QueryFactsClustersFactsClustersEntities(BaseModel):
    id: str
    name: Optional[str]


QueryFactsClusters.model_rebuild()
QueryFactsClustersFacts.model_rebuild()
QueryFactsClustersFactsResults.model_rebuild()
QueryFactsClustersFactsResultsMentions.model_rebuild()
QueryFactsClustersFactsResultsAssertions.model_rebuild()
QueryFactsClustersFactsResultsAssertionsMentions.model_rebuild()
QueryFactsClustersFactsClusters.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteEmotions(BaseModel):
    delete_emotions: Optional[list[Optional["DeleteEmotionsDeleteEmotions"]]] = Field(
        alias="deleteEmotions"
    )


class DeleteEmotionsDeleteEmotions(BaseModel):
    id: str
    state: EntityState


DeleteEmotions.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class RestartContent(BaseModel):
    restart_content: Optional["RestartContentRestartContent"] = Field(
        alias="restartContent"
    )


class RestartContentRestartContent(BaseModel):
    id: str
    state: EntityState


RestartContent.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import AgentTypes, EntityState


class CreateAgent(BaseModel):
    create_agent: Optional["CreateAgentCreateAgent"] = Field(alias="createAgent")


class CreateAgentCreateAgent(BaseModel):
    id: str
    name: str
    state: EntityState
    type: AgentTypes


CreateAgent.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalDrugs(BaseModel):
    delete_medical_drugs: Optional[
        list[Optional["DeleteMedicalDrugsDeleteMedicalDrugs"]]
    ] = Field(alias="deleteMedicalDrugs")


class DeleteMedicalDrugsDeleteMedicalDrugs(BaseModel):
    id: str
    state: EntityState


DeleteMedicalDrugs.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import CollectionTypes, EntityState


class AddConversationsToCollections(BaseModel):
    add_conversations_to_collections: Optional[
        list[Optional["AddConversationsToCollectionsAddConversationsToCollections"]]
    ] = Field(alias="addConversationsToCollections")


class AddConversationsToCollectionsAddConversationsToCollections(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[CollectionTypes]
    contents: Optional[
        list[
            Optional[
                "AddConversationsToCollectionsAddConversationsToCollectionsContents"
            ]
        ]
    ]


class AddConversationsToCollectionsAddConversationsToCollectionsContents(BaseModel):
    id: str
    name: str


AddConversationsToCollections.model_rebuild()
AddConversationsToCollectionsAddConversationsToCollections.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryTokens(BaseModel):
    tokens: Optional["QueryTokensTokens"]


class QueryTokensTokens(BaseModel):
    correlation_id: Optional[str] = Field(alias="correlationId")
    owner_id: Optional[str] = Field(alias="ownerId")
    embedding_input_tokens: Optional[int] = Field(alias="embeddingInputTokens")
    embedding_model_services: Optional[list[Optional[str]]] = Field(
        alias="embeddingModelServices"
    )
    completion_input_tokens: Optional[int] = Field(alias="completionInputTokens")
    completion_output_tokens: Optional[int] = Field(alias="completionOutputTokens")
    completion_model_services: Optional[list[Optional[str]]] = Field(
        alias="completionModelServices"
    )
    preparation_input_tokens: Optional[int] = Field(alias="preparationInputTokens")
    preparation_output_tokens: Optional[int] = Field(alias="preparationOutputTokens")
    preparation_model_services: Optional[list[Optional[str]]] = Field(
        alias="preparationModelServices"
    )
    extraction_input_tokens: Optional[int] = Field(alias="extractionInputTokens")
    extraction_output_tokens: Optional[int] = Field(alias="extractionOutputTokens")
    extraction_model_services: Optional[list[Optional[str]]] = Field(
        alias="extractionModelServices"
    )
    generation_input_tokens: Optional[int] = Field(alias="generationInputTokens")
    generation_output_tokens: Optional[int] = Field(alias="generationOutputTokens")
    generation_model_services: Optional[list[Optional[str]]] = Field(
        alias="generationModelServices"
    )


QueryTokens.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, LinkTypes


class QueryPersonsClusters(BaseModel):
    persons: Optional["QueryPersonsClustersPersons"]


class QueryPersonsClustersPersons(BaseModel):
    results: Optional[list[Optional["QueryPersonsClustersPersonsResults"]]]
    clusters: Optional["QueryPersonsClustersPersonsClusters"]


class QueryPersonsClustersPersonsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryPersonsClustersPersonsResultsOwner"
    state: EntityState
    alternate_names: Optional[list[Optional[str]]] = Field(alias="alternateNames")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    feeds: Optional[list[Optional["QueryPersonsClustersPersonsResultsFeeds"]]]
    links: Optional[list[Optional["QueryPersonsClustersPersonsResultsLinks"]]]
    workflow: Optional["QueryPersonsClustersPersonsResultsWorkflow"]
    location: Optional["QueryPersonsClustersPersonsResultsLocation"]
    h_3: Optional["QueryPersonsClustersPersonsResultsH3"] = Field(alias="h3")
    address: Optional["QueryPersonsClustersPersonsResultsAddress"]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")
    phone_number: Optional[str] = Field(alias="phoneNumber")
    birth_date: Optional[Any] = Field(alias="birthDate")
    title: Optional[str]
    occupation: Optional[str]
    education: Optional[str]
    works_for: Optional[
        list[Optional["QueryPersonsClustersPersonsResultsWorksFor"]]
    ] = Field(alias="worksFor")
    affiliation: Optional[
        list[Optional["QueryPersonsClustersPersonsResultsAffiliation"]]
    ]
    member_of: Optional[
        list[Optional["QueryPersonsClustersPersonsResultsMemberOf"]]
    ] = Field(alias="memberOf")
    alumni_of: Optional[
        list[Optional["QueryPersonsClustersPersonsResultsAlumniOf"]]
    ] = Field(alias="alumniOf")
    birth_place: Optional["QueryPersonsClustersPersonsResultsBirthPlace"] = Field(
        alias="birthPlace"
    )
    death_place: Optional["QueryPersonsClustersPersonsResultsDeathPlace"] = Field(
        alias="deathPlace"
    )
    home_location: Optional[
        list[Optional["QueryPersonsClustersPersonsResultsHomeLocation"]]
    ] = Field(alias="homeLocation")
    work_location: Optional[
        list[Optional["QueryPersonsClustersPersonsResultsWorkLocation"]]
    ] = Field(alias="workLocation")


class QueryPersonsClustersPersonsResultsOwner(BaseModel):
    id: str


class QueryPersonsClustersPersonsResultsFeeds(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")
    excerpts: Optional[str]


class QueryPersonsClustersPersonsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class QueryPersonsClustersPersonsResultsH3(BaseModel):
    h_3_r_0: Optional[str] = Field(alias="h3r0")
    h_3_r_1: Optional[str] = Field(alias="h3r1")
    h_3_r_2: Optional[str] = Field(alias="h3r2")
    h_3_r_3: Optional[str] = Field(alias="h3r3")
    h_3_r_4: Optional[str] = Field(alias="h3r4")
    h_3_r_5: Optional[str] = Field(alias="h3r5")
    h_3_r_6: Optional[str] = Field(alias="h3r6")
    h_3_r_7: Optional[str] = Field(alias="h3r7")
    h_3_r_8: Optional[str] = Field(alias="h3r8")
    h_3_r_9: Optional[str] = Field(alias="h3r9")
    h_3_r_10: Optional[str] = Field(alias="h3r10")
    h_3_r_11: Optional[str] = Field(alias="h3r11")
    h_3_r_12: Optional[str] = Field(alias="h3r12")
    h_3_r_13: Optional[str] = Field(alias="h3r13")
    h_3_r_14: Optional[str] = Field(alias="h3r14")
    h_3_r_15: Optional[str] = Field(alias="h3r15")


class QueryPersonsClustersPersonsResultsAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


class QueryPersonsClustersPersonsResultsWorksFor(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsAffiliation(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsMemberOf(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsAlumniOf(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsBirthPlace(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsDeathPlace(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsHomeLocation(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsWorkLocation(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsClusters(BaseModel):
    clusters: Optional[list["QueryPersonsClustersPersonsClustersClusters"]]


class QueryPersonsClustersPersonsClustersClusters(BaseModel):
    entities: list["QueryPersonsClustersPersonsClustersClustersEntities"]
    similarity: Optional[float]


class QueryPersonsClustersPersonsClustersClustersEntities(BaseModel):
    id: str
    name: Optional[str]


QueryPersonsClusters.model_rebuild()
QueryPersonsClustersPersons.model_rebuild()
QueryPersonsClustersPersonsResults.model_rebuild()
QueryPersonsClustersPersonsClusters.model_rebuild()
QueryPersonsClustersPersonsClustersClusters.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryCategories(BaseModel):
    categories: Optional["QueryCategoriesCategories"]


class QueryCategoriesCategories(BaseModel):
    results: Optional[list[Optional["QueryCategoriesCategoriesResults"]]]


class QueryCategoriesCategoriesResults(BaseModel):
    id: str
    name: str
    description: Optional[str]
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    feeds: Optional[list[Optional["QueryCategoriesCategoriesResultsFeeds"]]]


class QueryCategoriesCategoriesResultsFeeds(BaseModel):
    id: str
    name: str


QueryCategories.model_rebuild()
QueryCategoriesCategories.model_rebuild()
QueryCategoriesCategoriesResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ContentTypes,
    EntityState,
    FileTypes,
    FilterMode,
    ObservableTypes,
    ViewTypes,
)


class CreateView(BaseModel):
    create_view: Optional["CreateViewCreateView"] = Field(alias="createView")


class CreateViewCreateView(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ViewTypes]
    filter: Optional["CreateViewCreateViewFilter"]
    augmented_filter: Optional["CreateViewCreateViewAugmentedFilter"] = Field(
        alias="augmentedFilter"
    )


class CreateViewCreateViewFilter(BaseModel):
    date_range: Optional["CreateViewCreateViewFilterDateRange"] = Field(
        alias="dateRange"
    )
    in_last: Optional[Any] = Field(alias="inLast")
    in_next: Optional[Any] = Field(alias="inNext")
    creation_date_range: Optional["CreateViewCreateViewFilterCreationDateRange"] = (
        Field(alias="creationDateRange")
    )
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[list[ContentTypes]]
    file_types: Optional[list[FileTypes]] = Field(alias="fileTypes")
    formats: Optional[list[str]]
    file_extensions: Optional[list[str]] = Field(alias="fileExtensions")
    file_size_range: Optional["CreateViewCreateViewFilterFileSizeRange"] = Field(
        alias="fileSizeRange"
    )
    similar_contents: Optional[list["CreateViewCreateViewFilterSimilarContents"]] = (
        Field(alias="similarContents")
    )
    contents: Optional[list["CreateViewCreateViewFilterContents"]]
    feeds: Optional[list["CreateViewCreateViewFilterFeeds"]]
    workflows: Optional[list["CreateViewCreateViewFilterWorkflows"]]
    collections: Optional[list["CreateViewCreateViewFilterCollections"]]
    users: Optional[list["CreateViewCreateViewFilterUsers"]]
    observations: Optional[list["CreateViewCreateViewFilterObservations"]]
    or_: Optional[list["CreateViewCreateViewFilterOr"]] = Field(alias="or")
    and_: Optional[list["CreateViewCreateViewFilterAnd"]] = Field(alias="and")
    has_observations: Optional[bool] = Field(alias="hasObservations")
    has_feeds: Optional[bool] = Field(alias="hasFeeds")
    has_collections: Optional[bool] = Field(alias="hasCollections")
    has_workflows: Optional[bool] = Field(alias="hasWorkflows")
    collection_mode: Optional[FilterMode] = Field(alias="collectionMode")
    observation_mode: Optional[FilterMode] = Field(alias="observationMode")


class CreateViewCreateViewFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class CreateViewCreateViewFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class CreateViewCreateViewFilterFileSizeRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class CreateViewCreateViewFilterSimilarContents(BaseModel):
    id: str


class CreateViewCreateViewFilterContents(BaseModel):
    id: str


class CreateViewCreateViewFilterFeeds(BaseModel):
    id: str


class CreateViewCreateViewFilterWorkflows(BaseModel):
    id: str


class CreateViewCreateViewFilterCollections(BaseModel):
    id: str


class CreateViewCreateViewFilterUsers(BaseModel):
    id: str


class CreateViewCreateViewFilterObservations(BaseModel):
    type: ObservableTypes
    observable: "CreateViewCreateViewFilterObservationsObservable"
    states: Optional[list[EntityState]]


class CreateViewCreateViewFilterObservationsObservable(BaseModel):
    id: str


class CreateViewCreateViewFilterOr(BaseModel):
    feeds: Optional[list["CreateViewCreateViewFilterOrFeeds"]]
    workflows: Optional[list["CreateViewCreateViewFilterOrWorkflows"]]
    collections: Optional[list["CreateViewCreateViewFilterOrCollections"]]
    users: Optional[list["CreateViewCreateViewFilterOrUsers"]]
    observations: Optional[list["CreateViewCreateViewFilterOrObservations"]]


class CreateViewCreateViewFilterOrFeeds(BaseModel):
    id: str


class CreateViewCreateViewFilterOrWorkflows(BaseModel):
    id: str


class CreateViewCreateViewFilterOrCollections(BaseModel):
    id: str


class CreateViewCreateViewFilterOrUsers(BaseModel):
    id: str


class CreateViewCreateViewFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: "CreateViewCreateViewFilterOrObservationsObservable"
    states: Optional[list[EntityState]]


class CreateViewCreateViewFilterOrObservationsObservable(BaseModel):
    id: str


class CreateViewCreateViewFilterAnd(BaseModel):
    feeds: Optional[list["CreateViewCreateViewFilterAndFeeds"]]
    workflows: Optional[list["CreateViewCreateViewFilterAndWorkflows"]]
    collections: Optional[list["CreateViewCreateViewFilterAndCollections"]]
    users: Optional[list["CreateViewCreateViewFilterAndUsers"]]
    observations: Optional[list["CreateViewCreateViewFilterAndObservations"]]


class CreateViewCreateViewFilterAndFeeds(BaseModel):
    id: str


class CreateViewCreateViewFilterAndWorkflows(BaseModel):
    id: str


class CreateViewCreateViewFilterAndCollections(BaseModel):
    id: str


class CreateViewCreateViewFilterAndUsers(BaseModel):
    id: str


class CreateViewCreateViewFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: "CreateViewCreateViewFilterAndObservationsObservable"
    states: Optional[list[EntityState]]


class CreateViewCreateViewFilterAndObservationsObservable(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilter(BaseModel):
    date_range: Optional["CreateViewCreateViewAugmentedFilterDateRange"] = Field(
        alias="dateRange"
    )
    in_last: Optional[Any] = Field(alias="inLast")
    in_next: Optional[Any] = Field(alias="inNext")
    creation_date_range: Optional[
        "CreateViewCreateViewAugmentedFilterCreationDateRange"
    ] = Field(alias="creationDateRange")
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[list[ContentTypes]]
    file_types: Optional[list[FileTypes]] = Field(alias="fileTypes")
    formats: Optional[list[str]]
    file_extensions: Optional[list[str]] = Field(alias="fileExtensions")
    file_size_range: Optional["CreateViewCreateViewAugmentedFilterFileSizeRange"] = (
        Field(alias="fileSizeRange")
    )
    similar_contents: Optional[
        list["CreateViewCreateViewAugmentedFilterSimilarContents"]
    ] = Field(alias="similarContents")
    contents: Optional[list["CreateViewCreateViewAugmentedFilterContents"]]
    feeds: Optional[list["CreateViewCreateViewAugmentedFilterFeeds"]]
    workflows: Optional[list["CreateViewCreateViewAugmentedFilterWorkflows"]]
    collections: Optional[list["CreateViewCreateViewAugmentedFilterCollections"]]
    users: Optional[list["CreateViewCreateViewAugmentedFilterUsers"]]
    observations: Optional[list["CreateViewCreateViewAugmentedFilterObservations"]]
    or_: Optional[list["CreateViewCreateViewAugmentedFilterOr"]] = Field(alias="or")
    and_: Optional[list["CreateViewCreateViewAugmentedFilterAnd"]] = Field(alias="and")
    has_observations: Optional[bool] = Field(alias="hasObservations")
    has_feeds: Optional[bool] = Field(alias="hasFeeds")
    has_collections: Optional[bool] = Field(alias="hasCollections")
    has_workflows: Optional[bool] = Field(alias="hasWorkflows")
    collection_mode: Optional[FilterMode] = Field(alias="collectionMode")
    observation_mode: Optional[FilterMode] = Field(alias="observationMode")


class CreateViewCreateViewAugmentedFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class CreateViewCreateViewAugmentedFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class CreateViewCreateViewAugmentedFilterFileSizeRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class CreateViewCreateViewAugmentedFilterSimilarContents(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterContents(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterFeeds(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterWorkflows(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterCollections(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterUsers(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterObservations(BaseModel):
    type: ObservableTypes
    observable: "CreateViewCreateViewAugmentedFilterObservationsObservable"
    states: Optional[list[EntityState]]


class CreateViewCreateViewAugmentedFilterObservationsObservable(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterOr(BaseModel):
    feeds: Optional[list["CreateViewCreateViewAugmentedFilterOrFeeds"]]
    workflows: Optional[list["CreateViewCreateViewAugmentedFilterOrWorkflows"]]
    collections: Optional[list["CreateViewCreateViewAugmentedFilterOrCollections"]]
    users: Optional[list["CreateViewCreateViewAugmentedFilterOrUsers"]]
    observations: Optional[list["CreateViewCreateViewAugmentedFilterOrObservations"]]


class CreateViewCreateViewAugmentedFilterOrFeeds(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterOrWorkflows(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterOrCollections(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterOrUsers(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: "CreateViewCreateViewAugmentedFilterOrObservationsObservable"
    states: Optional[list[EntityState]]


class CreateViewCreateViewAugmentedFilterOrObservationsObservable(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterAnd(BaseModel):
    feeds: Optional[list["CreateViewCreateViewAugmentedFilterAndFeeds"]]
    workflows: Optional[list["CreateViewCreateViewAugmentedFilterAndWorkflows"]]
    collections: Optional[list["CreateViewCreateViewAugmentedFilterAndCollections"]]
    users: Optional[list["CreateViewCreateViewAugmentedFilterAndUsers"]]
    observations: Optional[list["CreateViewCreateViewAugmentedFilterAndObservations"]]


class CreateViewCreateViewAugmentedFilterAndFeeds(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterAndWorkflows(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterAndCollections(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterAndUsers(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: "CreateViewCreateViewAugmentedFilterAndObservationsObservable"
    states: Optional[list[EntityState]]


class CreateViewCreateViewAugmentedFilterAndObservationsObservable(BaseModel):
    id: str


CreateView.model_rebuild()
CreateViewCreateView.model_rebuild()
CreateViewCreateViewFilter.model_rebuild()
CreateViewCreateViewFilterObservations.model_rebuild()
CreateViewCreateViewFilterOr.model_rebuild()
CreateViewCreateViewFilterOrObservations.model_rebuild()
CreateViewCreateViewFilterAnd.model_rebuild()
CreateViewCreateViewFilterAndObservations.model_rebuild()
CreateViewCreateViewAugmentedFilter.model_rebuild()
CreateViewCreateViewAugmentedFilterObservations.model_rebuild()
CreateViewCreateViewAugmentedFilterOr.model_rebuild()
CreateViewCreateViewAugmentedFilterOrObservations.model_rebuild()
CreateViewCreateViewAugmentedFilterAnd.model_rebuild()
CreateViewCreateViewAugmentedFilterAndObservations.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class TriggerFeed(BaseModel):
    trigger_feed: Optional["TriggerFeedTriggerFeed"] = Field(alias="triggerFeed")


class TriggerFeedTriggerFeed(BaseModel):
    id: str
    state: EntityState


TriggerFeed.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ConversationTypes, EntityState


class BranchConversation(BaseModel):
    branch_conversation: Optional["BranchConversationBranchConversation"] = Field(
        alias="branchConversation"
    )


class BranchConversationBranchConversation(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ConversationTypes]


BranchConversation.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityTypes


class QueryConversationsGraph(BaseModel):
    conversations: Optional["QueryConversationsGraphConversations"]


class QueryConversationsGraphConversations(BaseModel):
    graph: Optional["QueryConversationsGraphConversationsGraph"]


class QueryConversationsGraphConversationsGraph(BaseModel):
    nodes: Optional[list[Optional["QueryConversationsGraphConversationsGraphNodes"]]]
    edges: Optional[list[Optional["QueryConversationsGraphConversationsGraphEdges"]]]


class QueryConversationsGraphConversationsGraphNodes(BaseModel):
    id: str
    name: str
    type: EntityTypes
    metadata: Optional[str]


class QueryConversationsGraphConversationsGraphEdges(BaseModel):
    from_: str = Field(alias="from")
    to: str
    relation: Optional[str]


QueryConversationsGraph.model_rebuild()
QueryConversationsGraphConversations.model_rebuild()
QueryConversationsGraphConversationsGraph.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalDevice(BaseModel):
    create_medical_device: Optional["CreateMedicalDeviceCreateMedicalDevice"] = Field(
        alias="createMedicalDevice"
    )


class CreateMedicalDeviceCreateMedicalDevice(BaseModel):
    id: str
    name: str


CreateMedicalDevice.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ObservableTypes


class ResolveEntity(BaseModel):
    resolve_entity: Optional["ResolveEntityResolveEntity"] = Field(
        alias="resolveEntity"
    )


class ResolveEntityResolveEntity(BaseModel):
    reference: Optional["ResolveEntityResolveEntityReference"]
    relevance: Optional[float]
    reasoning: Optional[str]


class ResolveEntityResolveEntityReference(BaseModel):
    type: ObservableTypes
    observable: "ResolveEntityResolveEntityReferenceObservable"


class ResolveEntityResolveEntityReferenceObservable(BaseModel):
    id: str
    name: Optional[str]


ResolveEntity.model_rebuild()
ResolveEntityResolveEntity.model_rebuild()
ResolveEntityResolveEntityReference.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountAgents(BaseModel):
    count_agents: Optional["CountAgentsCountAgents"] = Field(alias="countAgents")


class CountAgentsCountAgents(BaseModel):
    count: Optional[Any]


CountAgents.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryAsanaProjects(BaseModel):
    asana_projects: Optional["QueryAsanaProjectsAsanaProjects"] = Field(
        alias="asanaProjects"
    )


class QueryAsanaProjectsAsanaProjects(BaseModel):
    results: Optional[list[str]]


QueryAsanaProjects.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ModelServiceTypes, ModelTypes


class QueryModels(BaseModel):
    models: Optional["QueryModelsModels"]


class QueryModelsModels(BaseModel):
    results: Optional[list["QueryModelsModelsResults"]]


class QueryModelsModelsResults(BaseModel):
    uri: Optional[Any]
    name: str
    type: Optional[ModelTypes]
    service_type: Optional[ModelServiceTypes] = Field(alias="serviceType")
    model: Optional[str]
    model_type: Optional[str] = Field(alias="modelType")
    description: Optional[str]
    available_on: Optional[list[Optional[str]]] = Field(alias="availableOn")
    features: Optional["QueryModelsModelsResultsFeatures"]
    metadata: Optional["QueryModelsModelsResultsMetadata"]


class QueryModelsModelsResultsFeatures(BaseModel):
    key_features: Optional[list[Optional[str]]] = Field(alias="keyFeatures")
    strengths: Optional[list[Optional[str]]]
    use_cases: Optional[list[Optional[str]]] = Field(alias="useCases")


class QueryModelsModelsResultsMetadata(BaseModel):
    reasoning: Optional[bool]
    multilingual: Optional[bool]
    multimodal: Optional[bool]
    knowledge_cutoff: Optional[Any] = Field(alias="knowledgeCutoff")
    prompt_cost_per_million: Optional[float] = Field(alias="promptCostPerMillion")
    completion_cost_per_million: Optional[float] = Field(
        alias="completionCostPerMillion"
    )
    embeddings_cost_per_million: Optional[float] = Field(
        alias="embeddingsCostPerMillion"
    )
    reranking_cost_per_million: Optional[float] = Field(alias="rerankingCostPerMillion")
    context_window_tokens: Optional[int] = Field(alias="contextWindowTokens")
    max_output_tokens: Optional[int] = Field(alias="maxOutputTokens")
    deprecated: Optional[bool]
    deprecation_date: Optional[Any] = Field(alias="deprecationDate")


QueryModels.model_rebuild()
QueryModelsModels.model_rebuild()
QueryModelsModelsResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalTherapies(BaseModel):
    delete_medical_therapies: Optional[
        list[Optional["DeleteMedicalTherapiesDeleteMedicalTherapies"]]
    ] = Field(alias="deleteMedicalTherapies")


class DeleteMedicalTherapiesDeleteMedicalTherapies(BaseModel):
    id: str
    state: EntityState


DeleteMedicalTherapies.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import BillableMetrics, ContentTypes, EntityTypes, FileTypes, OperationTypes


class QueryUsage(BaseModel):
    usage: Optional[list[Optional["QueryUsageUsage"]]]


class QueryUsageUsage(BaseModel):
    id: Optional[str]
    correlation_id: Optional[str] = Field(alias="correlationId")
    date: Any
    credits: Optional[Any]
    name: str
    metric: Optional[BillableMetrics]
    workflow: Optional[str]
    entity_type: Optional[EntityTypes] = Field(alias="entityType")
    entity_id: Optional[str] = Field(alias="entityId")
    project_id: str = Field(alias="projectId")
    owner_id: str = Field(alias="ownerId")
    uri: Optional[str]
    duration: Optional[Any]
    throughput: Optional[float]
    content_type: Optional[ContentTypes] = Field(alias="contentType")
    file_type: Optional[FileTypes] = Field(alias="fileType")
    model_service: Optional[str] = Field(alias="modelService")
    model_name: Optional[str] = Field(alias="modelName")
    processor_name: Optional[str] = Field(alias="processorName")
    prompt_tokens: Optional[int] = Field(alias="promptTokens")
    completion_tokens: Optional[int] = Field(alias="completionTokens")
    tokens: Optional[int]
    count: Optional[int]
    operation: Optional[str]
    operation_type: Optional[OperationTypes] = Field(alias="operationType")


QueryUsage.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class RemoveContentLabel(BaseModel):
    remove_content_label: Optional["RemoveContentLabelRemoveContentLabel"] = Field(
        alias="removeContentLabel"
    )


class RemoveContentLabelRemoveContentLabel(BaseModel):
    id: str
    name: str


RemoveContentLabel.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteCategories(BaseModel):
    delete_categories: Optional[list[Optional["DeleteCategoriesDeleteCategories"]]] = (
        Field(alias="deleteCategories")
    )


class DeleteCategoriesDeleteCategories(BaseModel):
    id: str
    state: EntityState


DeleteCategories.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllMedicalIndications(BaseModel):
    delete_all_medical_indications: Optional[
        list[Optional["DeleteAllMedicalIndicationsDeleteAllMedicalIndications"]]
    ] = Field(alias="deleteAllMedicalIndications")


class DeleteAllMedicalIndicationsDeleteAllMedicalIndications(BaseModel):
    id: str
    state: EntityState


DeleteAllMedicalIndications.model_rebuild()
